(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    385828,       7240]
NotebookOptionsPosition[    362681,       6854]
NotebookOutlinePosition[    369589,       7008]
CellTagsIndexPosition[    369509,       7003]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar", "FirstSlide",
 CellMargins->{{0, 0}, {-1, 0}},
 CellTags->
  "SlideShowHeader",ExpressionUUID->"ae861ed8-5fa1-4088-84fd-2651cc7b368a"],

Cell["\<\
Import/Export
Updates and Applications\
\>", "Title",
 CellChangeTimes->{{3.843061759140668*^9, 
  3.843061767044368*^9}},ExpressionUUID->"8b1642a0-c2f2-4832-b962-\
da68c26a4047"],

Cell["Sean Cheren, Wolfram Research", "Subtitle",
 CellChangeTimes->{{3.8303528001076193`*^9, 3.830352822403953*^9}, {
  3.843061751464662*^9, 
  3.8430617562046747`*^9}},ExpressionUUID->"75c0d664-a0db-4889-a1b0-\
650f7c83e5d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"ee3ea2a1-973b-4e9a-a704-0d8a3c30d1be"],

Cell[CellGroupData[{

Cell["ABSTRACT", "Section",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.7257199329223537`*^9, 3.725720005948655*^9}, {
   3.72572008110417*^9, 3.725720088583918*^9}, {3.735906066467186*^9, 
   3.7359060766280823`*^9}, 3.7880100304206944`*^9, {3.788018566457625*^9, 
   3.788018567874702*^9}, {3.7880186005884113`*^9, 
   3.788018634852206*^9}},ExpressionUUID->"75e785bd-e551-42c4-b918-\
1ff722dfcee0"],

Cell["\<\
The Wolfram Language is constantly growing the ability to interact with a \
wide variety of data formats in faster and easier ways. In this talk, we will \
give details and examples of the new and updated formats coming in the next \
version of Wolfram Language. Specifically, we will talk about brand new \
exporters for statistics related formats, updates to metadata in image \
formats and scientific data formats, as well as a new features in the WL and \
PDF formats. We will also demonstrate some new functions coming in Wolfram \
Language to interact with the metadata of specific formats such as default \
elements, extensions, and MIME types. \
\>", "Text",
 CellChangeTimes->{
  3.843061864152339*^9},ExpressionUUID->"98832863-8e01-4636-a116-\
f2d361af161b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"4e8e5a7c-8b4e-47e7-a75d-3cb2b655ed51"],

Cell[CellGroupData[{

Cell["Stat Export", "Section",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, 
   3.7880179920575123`*^9, {3.843061842313799*^9, 
   3.843061843401561*^9}},ExpressionUUID->"bf6b684b-be70-47c1-be5a-\
c3838a1d25c9"],

Cell[CellGroupData[{

Cell["Basic Examples", "Subsection",
 CellChangeTimes->{{3.8430678533803988`*^9, 
  3.84306785639371*^9}},ExpressionUUID->"9e8c88a7-092a-4234-be6e-\
e6e70c1a3797"],

Cell[CellGroupData[{

Cell["Formats supported in Export:", "Item",
 CellChangeTimes->{{3.843068350225998*^9, 
  3.843068373720381*^9}},ExpressionUUID->"d36d72ec-fab4-4ccb-bcda-\
a4b7cf2f2ae8"],

Cell[CellGroupData[{

Cell["DTA", "Subitem",
 CellChangeTimes->{{3.843068350225998*^9, 
  3.8430683553003283`*^9}},ExpressionUUID->"f1baa397-a5b1-4c30-bf87-\
0a7bdffdb995"],

Cell["SAS7BDAT", "Subitem",
 CellChangeTimes->{{3.843068350225998*^9, 
  3.843068362483289*^9}},ExpressionUUID->"2bb1f54c-b682-46e6-8d23-\
e009f051e4ff"],

Cell["SAV", "Subitem",
 CellChangeTimes->{{3.843068350225998*^9, 
  3.843068368101224*^9}},ExpressionUUID->"cd7db606-7f17-4231-ab20-\
193990cfad34"],

Cell["XPORT", "Subitem",
 CellChangeTimes->{{3.843068350225998*^9, 
  3.843068368872628*^9}},ExpressionUUID->"73bf84a1-cf71-49d0-9fc7-\
125ee95ae0c1"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "6"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.84306312618366*^9, 3.843063140033092*^9}, {
  3.843068319984488*^9, 3.843068323988422*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"502b6fd1-3c50-42a2-8f4c-fa190536c5cd"],

Cell[BoxData[
 RowBox[{"Import", "[", "\"\<test.dta\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.843063144483501*^9, 3.843063151033339*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"acb54648-ea26-4c7f-9280-9ed3909d3153"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843130403886201*^9, 3.8431304050302277`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"d7fc74b4-8a2e-4fa6-bcc2-e9106fcbcf5c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Data Structures", "Subsection",
 CellChangeTimes->{{3.843068238266223*^9, 3.843068238781543*^9}, {
  3.84307228714093*^9, 
  3.843072290331977*^9}},ExpressionUUID->"af202b17-41eb-486b-b6a8-\
4e200549af59"],

Cell["Column names are inferred from Dataset", "Item",
 CellChangeTimes->{{3.8430793317719803`*^9, 
  3.8430793515188627`*^9}},ExpressionUUID->"790df0b5-52bc-4936-8497-\
57fae21c84ff"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.dta\>\"", ",", 
    TagBox[
     TagBox[
      DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = <|
       "InitialData" -> {<|"A" -> 1, "B" -> 2, "C" -> 3|>, <|
          "A" -> 4, "B" -> 5, "C" -> 6|>}, "AllowEmbedding" -> True, 
        "InitialShape" -> 
        TypeSystem`PackageScope`HeaderShape[<|{All, "A"} -> 1, {All, "B"} -> 
           1, {All, "C"} -> 1|>, 
          TypeSystem`PackageScope`Limited[
           TypeSystem`PackageScope`ColumnShape[
            TypeSystem`PackageScope`Limited[
             
             TypeSystem`PackageScope`RowShape[<|
              "A" -> TypeSystem`PackageScope`AtomShape[34], "B" -> 
               TypeSystem`PackageScope`AtomShape[34], "C" -> 
               TypeSystem`PackageScope`AtomShape[34]|>], 
             DirectedInfinity[1], 3, {All}]], 2, 
           DirectedInfinity[1], {}]], "InitialType" -> TypeSystem`Vector[
          TypeSystem`Struct[{"A", "B", "C"}, {
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer]}], 2], "Meta" -> <||>, "RowTarget" -> 20,
         "ColumnTarget" -> 10, "Shape" -> 
        TypeSystem`PackageScope`HeaderShape[<|{All, "A"} -> 1, {All, "B"} -> 
           1, {All, "C"} -> 1|>, 
          TypeSystem`PackageScope`Limited[
           TypeSystem`PackageScope`ColumnShape[
            TypeSystem`PackageScope`Limited[
             
             TypeSystem`PackageScope`RowShape[<|
              "A" -> TypeSystem`PackageScope`AtomShape[34], "B" -> 
               TypeSystem`PackageScope`AtomShape[34], "C" -> 
               TypeSystem`PackageScope`AtomShape[34]|>], 
             DirectedInfinity[1], 3, {All}]], 2, 
           DirectedInfinity[1], {}]], "Type" -> TypeSystem`Vector[
          TypeSystem`Struct[{"A", "B", "C"}, {
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer]}], 2], "Path" -> {}, "DisplayedRowCount" -> 
        2, "DisplayedColumnCount" -> 3, "DataRowCount" -> 2, 
        "DataColumnCount" -> 3, "SortPaths" -> {}, "SortDirections" -> {}, 
        "HiddenItemsMap" -> Null, "UpdateType" -> 1|>, 
       TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
       TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
       TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
       DynamicModule[{
        TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
           Style[
            Grid[{{
               Item[
                Pane[
                 Annotation[
                  EventHandler[
                   MouseAppearance[
                    Mouseover["A", 
                    Style[
                    "A", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                   If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "A"}, 1]]], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                   All, "A"}, "ColumnHeader", True], "Mouse"], 
                 ImageSize -> {{1, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
                GrayLevel[0.95], Alignment -> {Left, Baseline}], 
               Item[
                Pane[
                 Annotation[
                  EventHandler[
                   MouseAppearance[
                    Mouseover["B", 
                    Style[
                    "B", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                   If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "B"}, 1]]], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                   All, "B"}, "ColumnHeader", True], "Mouse"], 
                 ImageSize -> {{1, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
                GrayLevel[0.95], Alignment -> {Left, Baseline}], 
               Item[
                Pane[
                 Annotation[
                  EventHandler[
                   MouseAppearance[
                    Mouseover["C", 
                    Style[
                    "C", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                   If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "C"}, 1]]], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                   All, "C"}, "ColumnHeader", True], "Mouse"], 
                 ImageSize -> {{1, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
                GrayLevel[0.95], Alignment -> {Left, Baseline}]}, {
               Item[
                Pane[
                 Annotation[
                  RawBoxes["1"], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                    Key["A"]}, "Item", False], "Mouse"], 
                 ImageSize -> {{34, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], 
                ItemSize -> {Full, Automatic}], 
               Item[
                Pane[
                 Annotation[
                  RawBoxes["2"], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                    Key["B"]}, "Item", False], "Mouse"], 
                 ImageSize -> {{34, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], 
                ItemSize -> {Full, Automatic}], 
               Item[
                Pane[
                 Annotation[
                  RawBoxes["3"], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                    Key["C"]}, "Item", False], "Mouse"], 
                 ImageSize -> {{34, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], 
                ItemSize -> {Full, Automatic}]}, {
               Item[
                Pane[
                 Annotation[
                  RawBoxes["4"], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                    Key["A"]}, "Item", False], "Mouse"], 
                 ImageSize -> {{34, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], 
                ItemSize -> {Full, Automatic}], 
               Item[
                Pane[
                 Annotation[
                  RawBoxes["5"], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                    Key["B"]}, "Item", False], "Mouse"], 
                 ImageSize -> {{34, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], 
                ItemSize -> {Full, Automatic}], 
               Item[
                Pane[
                 Annotation[
                  RawBoxes["6"], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                    Key["C"]}, "Item", False], "Mouse"], 
                 ImageSize -> {{34, Full}, Automatic}, 
                 ImageMargins -> {{5, 3}, {4, 5}}], 
                ItemSize -> {Full, Automatic}]}}, 
             BaseStyle -> {
              ContextMenu -> 
               Dynamic[
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                 Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                   TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                   TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger, TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu,
                    True, TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger = 
                    TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                   TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                    Block[{TypeSystem`NestedGrid`PackagePrivate`$\
globalScrollPos = {TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                    
                    With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    "Show " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    "Hide " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], Nothing]}]]]]], FontFamily -> 
               "Source Sans Pro", FontSize -> 14, FontWeight -> Plain}, 
             Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
             Spacings -> {0, 0}, Alignment -> Left, 
             BaseStyle -> {
              FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
               Plain}], LineBreakWithin -> False, ContextMenu -> {}, 
            NumberMarks -> False, ShowAutoStyles -> False]], 
         TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
        Dynamic[
         TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
         TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
            Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
            
            Module[{TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
              TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
              TypeSystem`NestedGrid`PackagePrivate`datasetData[
               TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
             TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
                FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
                TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
                TypeSystem`NestedGrid`PackagePrivate`renderGrid[
                TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                 TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
               Not[
                FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
               TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
               TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
          TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
          TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
            FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
            TypeSystem`SparseGrid[
             TypeSystem`H["(data no longer present)"]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid]], 
         TrackedSymbols :> {
          TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
           TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
        DynamicModuleValues :> {}], 
       TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
        TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
         TypeSystem`PackageScope`SubViewPathbar[
         TypeSystem`NestedGrid`PackagePrivate`$path$$, 
          TypeSystem`NestedGrid`PackagePrivate`updateState[
          TypeSystem`NestedGrid`PackagePrivate`$state$$, 
           TypeSystem`NestedGrid`PackagePrivate`$path$$, 
           TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
           TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
           TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
        TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
       TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
        Framed[
         Dynamic[
          Replace[
          TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
           TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
              Blank[]] -> "", 
            TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
              Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
               Blank[]], 
              Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
               Blank[]], 
              Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
               Blank[]]] :> (
             Increment[
              TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
             TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
              TypeSystem`NestedGrid`PackagePrivate`path$; 
             TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
              TypeSystem`NestedGrid`PackagePrivate`pathType$; 
             TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
              TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
             TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
               TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
             TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
              TypeSystem`NestedGrid`PackagePrivate`path$, 
               TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
            Spacer[10], Blank[] :> Spacer[10]}], 
          TrackedSymbols :> {
           TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], 
         FrameStyle -> None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> 
         Top, ImageSize -> {Automatic, 15}], FontSize -> 1], 
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
       DynamicWrapperBox[
        DynamicBox[ToBoxes[
          Dataset`DatasetContent[
          2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
           "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], 
           "State" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], 
           "VPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], 
           "HPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], 
           "TopBar" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], 
           "BottomBar" -> 
           Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], 
           "OutputID" -> Hold[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], 
          StandardForm],
         ImageSizeCache->{128., {41.45765625, 57.54234375}},
         TrackedSymbols:>{
          TypeSystem`NestedGrid`PackagePrivate`$state$$, 
           TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
        MouseAnnotation[],
        ImageSizeCache->{128., {41.45765625, 57.54234375}}],
       BaseStyle->{LineBreakWithin -> False},
       DynamicModuleValues:>{},
       Initialization:>(TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = 
        CreateUUID[]),
       UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
      Deploy,
      DefaultBaseStyle->"Deploy"],
     Dataset`InterpretDataset[1],
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.8430794612611113`*^9, 3.843079465081266*^9}, {
  3.843079511344913*^9, 3.843079513498426*^9}, {3.8431300792280073`*^9, 
  3.843130096040144*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"715fecb0-b941-4c6c-8ba2-d6f8afc233fa"],

Cell["Associations are named columns", "Item",
 CellChangeTimes->{{3.843079594682168*^9, 3.843079616255427*^9}, {
   3.843079657344667*^9, 3.8430796669288607`*^9}, 
   3.843079953988962*^9},ExpressionUUID->"d0cedc16-6bfd-4dce-87f3-\
573203ba9d0b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.dta\>\"", ",", 
    RowBox[{"<|", 
     RowBox[{
      RowBox[{"\"\<A\>\"", "->", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ",", 
      RowBox[{"\"\<B\>\"", "->", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}]}]}], "|>"}]}], "]"}], 
  ";"}], "\n", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<ColumnDescriptions\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.843079633762931*^9, 3.8430796530579033`*^9}, 
   3.843079948940184*^9, {3.8430800745843678`*^9, 3.843080077087021*^9}, {
   3.8431301050288258`*^9, 3.843130106294146*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"a1f14626-5810-40fd-9f5b-588a1745c6ef"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Data\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843079668868206*^9, 3.8430796942178783`*^9}, {
  3.8430797330451717`*^9, 3.8430797333772373`*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"11300029-3b7e-49d4-90f6-bbd6aecf00f3"],

Cell["Missing is supported:", "Item",
 CellChangeTimes->{{3.8430800807178717`*^9, 
  3.843080083403529*^9}},ExpressionUUID->"62a72e39-8e66-4899-997e-\
8798ab9e0fe2"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   RowBox[{"<|", 
    RowBox[{
     RowBox[{"\"\<A\>\"", "->", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ",", 
     RowBox[{"\"\<B\>\"", "->", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5", ",", 
        RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "}"}]}]}], 
    "|>"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843080086163329*^9, 3.843080092643516*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"df682cf9-4703-4999-80c0-74111c847179"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843080102523875*^9, 3.843080102657852*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"44db3ed2-8f32-41c6-92f2-ef075ec03fc0"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<ColumnDescriptions\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843080106579043*^9, 3.8430801086988993`*^9}, {
  3.843080237383747*^9, 3.843080242297669*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"cd0c602f-eed9-42f2-a7d6-b8f94a328630"],

Cell["\<\
Most tabular data structures in WL are automagically supported:\
\>", "Item",
 CellChangeTimes->{{3.843129913158868*^9, 
  3.8431299233227863`*^9}},ExpressionUUID->"5271e6fc-a5d1-4fbf-8558-\
1cab99dd2507"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.dta\>\"", ",", 
    InterpretationBox[
     RowBox[{
      TagBox["TimeSeries",
       "SummaryHead"], "[", 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False->GridBox[{
           {
            PaneBox[
             ButtonBox[
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"],
               ImageSizeCache->{12., {0., 12.}}],
              Appearance->None,
              ButtonFunction:>(Typeset`open$$ = True),
              Evaluator->Automatic,
              Method->"Preemptive"],
             Alignment->{Center, Center},
             
             ImageSize->
              Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{}, {}, 
              {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6],
                Opacity[1.], LineBox[CompressedData["
1:eJwVkns4lQcAh0+uc0bjnO/7jkudi/t9bBijfb/S3G+zmjJJzO0pJMYzZCGt
Hq1YZ7aZSC7N3A6WPTaXo04NI3tGndDM0fQoHIyHcjuzP97n/ff94xVEJgVH
KzEYDLcd/rf6By00g7FIv2r0FysUCjq3dERpqGaZzo6y2rI7ukkLf5L60aVr
9Clf81Zx1Et6KL199kLABm1/0YP4rHmFDlkaKnlPvk3X7raL7tFZon/9PmrG
N3EXTodVqG1JVujjwgc2/7gro1CuKvefWqcDl2udBqGK0Rf3VD/qYSC6odwz
0UEdW3ymoZaSCrQ7VZQz1TRwb1pddZCpDrW3x3IeK5hgHqby2IeZKNzm1lVI
NbEYPPFbZKwW9ptkPzGs2Y22PrbWXkdt8EZr4tb9teHQLVb2k+og1sfDWc9Z
B7uy+o99foyNEfn1+ElHFjSvhKmmqZB4KFYqV36Tjaj9Ta2iSgo39pXXhnEI
sEPZEx9ucFA0v0yGs0k8dRqyne/lwM/rXMjX2yS6jFsFU99xYP1Isp66RUGS
WF0yE8PBjSLqpmiNg8mpE/VPHDiYWCvnGsp0oR7nEWGtxsGBItmm64Qejnq7
lHw5TOH0w1BRQb8+2lwPpflUUbD3lMW+02IAyyMusyufUtCd4+UUNOxB7x/W
z0TuFPpci5PIb/ciOdQrr5fY6e2SdHsWc+GBMzVLMhLMJAbx6CoP9kExka+J
SPCm27n+bnyYJeeKM3JI+NUHfpL3Cx9e8vqq7QASE145wkN2AqRmKSwneCTe
zWq/P1wpQJvDHp+6JQLmfYMWZgJDGHl7LlzqJpA5ezadLDZEaWKJk6SQwAkz
5qqUMAIWN5S1wwnUO7913LHACPLc/JSfbQn0TEb0Q2GEVno0049BIP7myRj+
WWP8eVA6gHUCaS6s+ZJ/jTF3xnjMcZoE9UJY9TzZBNYjFt7DTymcs+eGP5Ob
gBHl1jHwFweBAe5K2VGmKCu9oLJ5Xxei8welz2WmiNC41Dh8Vw9phbLixRAz
zPHv2sia9Hf+yT9S/bsZNGOYzT7fGMBiQcXX1tscjYLV+MoEAzSf45sHd5mj
bLur6eM8fQxY6Tr57LNA3A9D107m66E5gfJYbLdAmfFwCu+yLjbOi2Bvawnm
aln29UoOHt82PeVRb4kgYYtZyi0K+h3OuasCKwx8cWWD1UFCPm7al1FhBWOv
lgRmJ4HLXxmwGrjWmBnrHa++w8ZVbv37GdesMXXnVurroyyYSHR/NGDZoC39
QV3vuA74tOBVyEUbiHM6tYIWtPH3bY2XCoUNDgjn3mAwtPEfcc2bPQ==
                "]]}},
             AspectRatio->1,
             Axes->{False, False},
             AxesLabel->{None, None},
             AxesOrigin->{0, 0.4},
             DisplayFunction->Identity,
             Frame->{{True, True}, {True, True}},
             FrameLabel->{{None, None}, {None, None}},
             FrameStyle->Directive[
               Opacity[0.5], 
               Thickness[Tiny], 
               RGBColor[0.368417, 0.506779, 0.709798]],
             FrameTicks->{{None, None}, {None, None}},
             GridLines->{None, None},
             GridLinesStyle->Directive[
               GrayLevel[0.5, 0.4]],
             
             ImageSize->
              Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             
             Method->{
              "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
               AbsolutePointSize[6], "ScalingFunctions" -> None},
             PlotRange->{{1, 15}, {1.0668348267217118`, 6.897745863208467}},
             PlotRangeClipping->True,
             PlotRangePadding->{{
                Scaled[0.1], 
                Scaled[0.1]}, {
                Scaled[0.1], 
                Scaled[0.1]}},
             Ticks->{Automatic, Automatic}], GridBox[{
              {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}], 
                  RowBox[{
                    TagBox["\" to \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["15", "SummaryItem"]}]},
                 "RowDefault"],
                "SummaryItem"], "\[SpanFromLeft]"},
              {
               RowBox[{
                TagBox["\<\"Data points: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["6",
                 "SummaryItem"]}], "\[SpanFromLeft]"}
             },
             AutoDelete->False,
             
             BaseStyle->{
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False},
             
             GridBoxAlignment->{
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
          },
          AutoDelete->False,
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Rows" -> {{Top}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->
         GridBox[{
           {
            PaneBox[
             ButtonBox[
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]],
              Appearance->None,
              ButtonFunction:>(Typeset`open$$ = False),
              Evaluator->Automatic,
              Method->"Preemptive"],
             Alignment->{Center, Center},
             
             ImageSize->
              Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{}, {}, 
              {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6],
                Opacity[1.], LineBox[CompressedData["
1:eJwVkns4lQcAh0+uc0bjnO/7jkudi/t9bBijfb/S3G+zmjJJzO0pJMYzZCGt
Hq1YZ7aZSC7N3A6WPTaXo04NI3tGndDM0fQoHIyHcjuzP97n/ff94xVEJgVH
KzEYDLcd/rf6By00g7FIv2r0FysUCjq3dERpqGaZzo6y2rI7ukkLf5L60aVr
9Clf81Zx1Et6KL199kLABm1/0YP4rHmFDlkaKnlPvk3X7raL7tFZon/9PmrG
N3EXTodVqG1JVujjwgc2/7gro1CuKvefWqcDl2udBqGK0Rf3VD/qYSC6odwz
0UEdW3ymoZaSCrQ7VZQz1TRwb1pddZCpDrW3x3IeK5hgHqby2IeZKNzm1lVI
NbEYPPFbZKwW9ptkPzGs2Y22PrbWXkdt8EZr4tb9teHQLVb2k+og1sfDWc9Z
B7uy+o99foyNEfn1+ElHFjSvhKmmqZB4KFYqV36Tjaj9Ta2iSgo39pXXhnEI
sEPZEx9ucFA0v0yGs0k8dRqyne/lwM/rXMjX2yS6jFsFU99xYP1Isp66RUGS
WF0yE8PBjSLqpmiNg8mpE/VPHDiYWCvnGsp0oR7nEWGtxsGBItmm64Qejnq7
lHw5TOH0w1BRQb8+2lwPpflUUbD3lMW+02IAyyMusyufUtCd4+UUNOxB7x/W
z0TuFPpci5PIb/ciOdQrr5fY6e2SdHsWc+GBMzVLMhLMJAbx6CoP9kExka+J
SPCm27n+bnyYJeeKM3JI+NUHfpL3Cx9e8vqq7QASE145wkN2AqRmKSwneCTe
zWq/P1wpQJvDHp+6JQLmfYMWZgJDGHl7LlzqJpA5ezadLDZEaWKJk6SQwAkz
5qqUMAIWN5S1wwnUO7913LHACPLc/JSfbQn0TEb0Q2GEVno0049BIP7myRj+
WWP8eVA6gHUCaS6s+ZJ/jTF3xnjMcZoE9UJY9TzZBNYjFt7DTymcs+eGP5Ob
gBHl1jHwFweBAe5K2VGmKCu9oLJ5Xxei8welz2WmiNC41Dh8Vw9phbLixRAz
zPHv2sia9Hf+yT9S/bsZNGOYzT7fGMBiQcXX1tscjYLV+MoEAzSf45sHd5mj
bLur6eM8fQxY6Tr57LNA3A9D107m66E5gfJYbLdAmfFwCu+yLjbOi2Bvawnm
aln29UoOHt82PeVRb4kgYYtZyi0K+h3OuasCKwx8cWWD1UFCPm7al1FhBWOv
lgRmJ4HLXxmwGrjWmBnrHa++w8ZVbv37GdesMXXnVurroyyYSHR/NGDZoC39
QV3vuA74tOBVyEUbiHM6tYIWtPH3bY2XCoUNDgjn3mAwtPEfcc2bPQ==
                "]]}},
             AspectRatio->1,
             Axes->{False, False},
             AxesLabel->{None, None},
             AxesOrigin->{0, 0.4},
             DisplayFunction->Identity,
             Frame->{{True, True}, {True, True}},
             FrameLabel->{{None, None}, {None, None}},
             FrameStyle->Directive[
               Opacity[0.5], 
               Thickness[Tiny], 
               RGBColor[0.368417, 0.506779, 0.709798]],
             FrameTicks->{{None, None}, {None, None}},
             GridLines->{None, None},
             GridLinesStyle->Directive[
               GrayLevel[0.5, 0.4]],
             
             ImageSize->
              Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             
             Method->{
              "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
               AbsolutePointSize[6], "ScalingFunctions" -> None},
             PlotRange->{{1, 15}, {1.0668348267217118`, 6.897745863208467}},
             PlotRangeClipping->True,
             PlotRangePadding->{{
                Scaled[0.1], 
                Scaled[0.1]}, {
                Scaled[0.1], 
                Scaled[0.1]}},
             Ticks->{Automatic, Automatic}], GridBox[{
              {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}], 
                  RowBox[{
                    TagBox["\" to \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["15", "SummaryItem"]}]},
                 "RowDefault"],
                "SummaryItem"], "\[SpanFromLeft]"},
              {
               RowBox[{
                TagBox["\<\"Data points: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["6",
                 "SummaryItem"]}], "\[SpanFromLeft]"},
              {
               RowBox[{
                TagBox["\<\"Regular: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["False",
                 "SummaryItem"]}], 
               RowBox[{
                TagBox["\<\"Output dimension: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["1",
                 "SummaryItem"]}]},
              {
               RowBox[{
                TagBox["\<\"Metadata: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["None",
                 "SummaryItem"]}], 
               RowBox[{
                TagBox["\<\"Minimum increment: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["1",
                 "SummaryItem"]}]},
              {
               TagBox["\<\"\"\>",
                "SummaryItem"], 
               RowBox[{
                TagBox["\<\"Resampling: \"\>",
                 "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                TagBox["\<\"LinearInterpolation\"\>",
                 "SummaryItem"]}]}
             },
             AutoDelete->False,
             
             BaseStyle->{
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False},
             
             GridBoxAlignment->{
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
          },
          AutoDelete->False,
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Rows" -> {{Top}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
         Typeset`open$$],
         ImageSize->Automatic],
        BaselinePosition->Baseline],
       DynamicModuleValues:>{}], "]"}],
     TemporalData[
     TimeSeries, {{{2, 1, 6, 5, 7, 4}}, {{{1, 2, 5, 10, 12, 15}}}, 1, {
       "Continuous", 1}, {"Discrete", 1}, 1, {
       ResamplingMethod -> {"Interpolation", InterpolationOrder -> 1}}}, 
      False, 10.1],
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "]"}], ";"}], "\n", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.843129933180669*^9, 3.843129983735862*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"7ff07c76-a44f-42e6-9d88-f52ba37b00d6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.dta\>\"", ",", 
    TagBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1", "2"},
        {"3", "4"}
       },
       GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}}], "\[NoBreak]", ")"}],
     Function[BoxForm`e$, 
      MatrixForm[BoxForm`e$]]]}], "]"}], ";"}], "\n", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.843129933180669*^9, 3.843130010907236*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"9d0c3ab6-f4de-4378-92e5-757b26e5779a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Type Detection", "Subsection",
 CellChangeTimes->{{3.843067858833733*^9, 
  3.8430678656021633`*^9}},ExpressionUUID->"aef62cb9-b7a5-455a-b635-\
362bd44052d4"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "6"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.84306312618366*^9, 3.843063140033092*^9}, {
   3.843068319984488*^9, 3.843068323988422*^9}, 3.8430724286736393`*^9},
 CellLabel->
  "In[108]:=",ExpressionUUID->"62944768-0ff4-4af2-840f-e20654c1efe6"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843063144483501*^9, 3.843063151033339*^9}, {
  3.843072433115075*^9, 3.843072434193432*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"72daceaa-a054-4622-ad1d-8530c54499c4"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<ColumnDescriptions\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8430761448409157`*^9, 3.843076148640911*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"8d552502-2804-40e8-ad87-cc52fdf25213"]
}, Closed]],

Cell[CellGroupData[{

Cell["Column Name and Type Control", "Subsection",
 CellChangeTimes->{{3.843067876640901*^9, 
  3.843067886896406*^9}},ExpressionUUID->"6e4a22cb-89c2-4cc6-9984-\
e41a25b45457"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"\"\<ColumnDescriptions\>\"", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[LeftAssociation]", 
       RowBox[{
        RowBox[{"\"\<Name\>\"", "\[Rule]", "\"\<COL1\>\""}], ",", 
        RowBox[{"\"\<Description\>\"", "\[Rule]", "\"\<\>\""}], ",", 
        RowBox[{"\"\<Type\>\"", "\[Rule]", "\"\<Real64\>\""}]}], 
       "\[RightAssociation]"}], ",", 
      RowBox[{"\[LeftAssociation]", 
       RowBox[{
        RowBox[{"\"\<Name\>\"", "\[Rule]", "\"\<COL2\>\""}], ",", 
        RowBox[{"\"\<Description\>\"", "\[Rule]", "\"\<\>\""}], ",", 
        RowBox[{"\"\<Type\>\"", "\[Rule]", "\"\<Real64\>\""}]}], 
       "\[RightAssociation]"}], ",", 
      RowBox[{"\[LeftAssociation]", 
       RowBox[{
        RowBox[{"\"\<Name\>\"", "\[Rule]", "\"\<COL3\>\""}], ",", 
        RowBox[{"\"\<Description\>\"", "\[Rule]", "\"\<\>\""}], ",", 
        RowBox[{"\"\<Type\>\"", "\[Rule]", "\"\<Real64\>\""}]}], 
       "\[RightAssociation]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843076132801683*^9, 3.843076179392684*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"9056215b-2d11-457c-8a75-769ab056e1e4"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]], "Input",
 CellLabel->
  "In[112]:=",ExpressionUUID->"f00fa283-326d-4a0e-8093-b259688cb525"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<ColumnDescriptions\>\""}], 
  "]"}]], "Input",
 CellLabel->
  "In[113]:=",ExpressionUUID->"86207e90-a9de-448c-b85a-a9558e217214"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   TagBox[
    TagBox[
     DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = <|
      "InitialData" -> {<|"COL1" -> 1., "COL2" -> 2., "COL3" -> 3.|>, <|
         "COL1" -> 4., "COL2" -> 5., "COL3" -> 6.|>}, "AllowEmbedding" -> 
       True, "InitialShape" -> 
       TypeSystem`PackageScope`HeaderShape[<|{All, "COL1"} -> 
          1, {All, "COL2"} -> 1, {All, "COL3"} -> 1|>, 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`Limited[
            
            TypeSystem`PackageScope`RowShape[<|
             "COL1" -> TypeSystem`PackageScope`AtomShape[60], "COL2" -> 
              TypeSystem`PackageScope`AtomShape[60], "COL3" -> 
              TypeSystem`PackageScope`AtomShape[60]|>], 
            DirectedInfinity[1], 3, {All}]], 2, 
          DirectedInfinity[1], {}]], "InitialType" -> TypeSystem`Vector[
         TypeSystem`Struct[{"COL1", "COL2", "COL3"}, {
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real]}], 2], "Meta" -> <||>, "RowTarget" -> 20, 
       "ColumnTarget" -> 10, "Shape" -> 
       TypeSystem`PackageScope`HeaderShape[<|{All, "COL1"} -> 
          1, {All, "COL2"} -> 1, {All, "COL3"} -> 1|>, 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`Limited[
            
            TypeSystem`PackageScope`RowShape[<|
             "COL1" -> TypeSystem`PackageScope`AtomShape[60], "COL2" -> 
              TypeSystem`PackageScope`AtomShape[60], "COL3" -> 
              TypeSystem`PackageScope`AtomShape[60]|>], 
            DirectedInfinity[1], 3, {All}]], 2, 
          DirectedInfinity[1], {}]], "Type" -> TypeSystem`Vector[
         TypeSystem`Struct[{"COL1", "COL2", "COL3"}, {
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real]}], 2], "Path" -> {}, "DisplayedRowCount" -> 
       2, "DisplayedColumnCount" -> 3, "DataRowCount" -> 2, "DataColumnCount" -> 
       3, "SortPaths" -> {}, "SortDirections" -> {}, "HiddenItemsMap" -> Null,
        "UpdateType" -> 1|>, TypeSystem`NestedGrid`PackagePrivate`$outputID$$,
       TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
      TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
      DynamicModule[{
       TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
          Style[
           Grid[{{
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL1", 
                    Style[
                    "COL1", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL1"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL1"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}], 
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL2", 
                    Style[
                    "COL2", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL2"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL2"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}], 
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL3", 
                    Style[
                    "COL3", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL3"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL3"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}]}, {
              Item[
               Pane[
                Annotation[
                 RawBoxes["1.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL1"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["2.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL2"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["3.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL3"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}]}, {
              Item[
               Pane[
                Annotation[
                 RawBoxes["4.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL1"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["5.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL2"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["6.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL3"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}]}}, 
            BaseStyle -> {
             ContextMenu -> 
              Dynamic[TypeSystem`NestedGrid`PackagePrivate`$\
contextMenuTrigger; 
                Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                  TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                  TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger, TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu,
                   True, TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger = 
                   TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                  TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                   Block[{TypeSystem`NestedGrid`PackagePrivate`$\
globalScrollPos = {TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                    
                    With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    "Show " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    "Hide " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], Nothing]}]]]]], FontFamily -> 
              "Source Sans Pro", FontSize -> 14, FontWeight -> Plain}, 
            Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
            Spacings -> {0, 0}, Alignment -> Left, 
            BaseStyle -> {
             FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
              Plain}], LineBreakWithin -> False, ContextMenu -> {}, 
           NumberMarks -> False, ShowAutoStyles -> False]], 
        TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
       Dynamic[
        TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
        TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
           Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
           
           Module[{TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
             TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
             TypeSystem`NestedGrid`PackagePrivate`datasetData[
              TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
               FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
               TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
               TypeSystem`NestedGrid`PackagePrivate`renderGrid[
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
               TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
              Not[
               FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
              TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
              TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
         TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
         TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
         TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
           FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
           TypeSystem`SparseGrid[
            TypeSystem`H["(data no longer present)"]], 
           TypeSystem`NestedGrid`PackagePrivate`renderedGrid]], 
        TrackedSymbols :> {
         TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
       DynamicModuleValues :> {}], 
      TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
       TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
        TypeSystem`PackageScope`SubViewPathbar[
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
         TypeSystem`NestedGrid`PackagePrivate`updateState[
         TypeSystem`NestedGrid`PackagePrivate`$state$$, 
          TypeSystem`NestedGrid`PackagePrivate`$path$$, 
          TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
       TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
      TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
       Framed[
        Dynamic[
         Replace[
         TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
          TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
             Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
              Blank[]], 
             Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
              Blank[]], 
             Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
              Blank[]]] :> (
            Increment[
             TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
             TypeSystem`NestedGrid`PackagePrivate`path$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
             TypeSystem`NestedGrid`PackagePrivate`pathType$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
             TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
             TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
            TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
             TypeSystem`NestedGrid`PackagePrivate`path$, 
              TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
           Spacer[10], Blank[] :> Spacer[10]}], 
         TrackedSymbols :> {
          TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], 
        FrameStyle -> None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> 
        Top, ImageSize -> {Automatic, 15}], FontSize -> 1], 
      TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
      DynamicWrapperBox[
       DynamicBox[ToBoxes[
         Dataset`DatasetContent[
         2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
          "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], 
          "State" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], 
          "VPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], 
          "HPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], 
          "TopBar" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], 
          "BottomBar" -> 
          Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
          Hold[
            TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
        ImageSizeCache->{206., {41.45765625, 57.54234375}},
        TrackedSymbols:>{
         TypeSystem`NestedGrid`PackagePrivate`$state$$, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
       MouseAnnotation[],
       ImageSizeCache->{206., {41.45765625, 57.54234375}}],
      BaseStyle->{LineBreakWithin -> False},
      DynamicModuleValues:>{},
      Initialization:>(TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = 
       CreateUUID[]),
      UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
     Deploy,
     DefaultBaseStyle->"Deploy"],
    Dataset`InterpretDataset[1],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   RowBox[{"\"\<ColumnDescriptions\>\"", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843130537312949*^9, 3.843130570573513*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"b80b1830-73e9-45cf-8a25-a92bd435e011"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<Dataset\>\""}], "]"}]], "Input",
 CellLabel->
  "In[117]:=",ExpressionUUID->"a43d9c84-9a4c-4b05-9163-9d08117d5647"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   TagBox[
    TagBox[
     DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = <|
      "InitialData" -> {<|"COL1" -> 1., "COL2" -> 2., "COL3" -> 3.|>, <|
         "COL1" -> 4., "COL2" -> 5., "COL3" -> 6.|>}, "AllowEmbedding" -> 
       True, "InitialShape" -> 
       TypeSystem`PackageScope`HeaderShape[<|{All, "COL1"} -> 
          1, {All, "COL2"} -> 1, {All, "COL3"} -> 1|>, 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`Limited[
            
            TypeSystem`PackageScope`RowShape[<|
             "COL1" -> TypeSystem`PackageScope`AtomShape[60], "COL2" -> 
              TypeSystem`PackageScope`AtomShape[60], "COL3" -> 
              TypeSystem`PackageScope`AtomShape[60]|>], 
            DirectedInfinity[1], 3, {All}]], 2, 
          DirectedInfinity[1], {}]], "InitialType" -> TypeSystem`Vector[
         TypeSystem`Struct[{"COL1", "COL2", "COL3"}, {
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real]}], 2], "Meta" -> <||>, "RowTarget" -> 20, 
       "ColumnTarget" -> 10, "Shape" -> 
       TypeSystem`PackageScope`HeaderShape[<|{All, "COL1"} -> 
          1, {All, "COL2"} -> 1, {All, "COL3"} -> 1|>, 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`Limited[
            
            TypeSystem`PackageScope`RowShape[<|
             "COL1" -> TypeSystem`PackageScope`AtomShape[60], "COL2" -> 
              TypeSystem`PackageScope`AtomShape[60], "COL3" -> 
              TypeSystem`PackageScope`AtomShape[60]|>], 
            DirectedInfinity[1], 3, {All}]], 2, 
          DirectedInfinity[1], {}]], "Type" -> TypeSystem`Vector[
         TypeSystem`Struct[{"COL1", "COL2", "COL3"}, {
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real]}], 2], "Path" -> {}, "DisplayedRowCount" -> 
       2, "DisplayedColumnCount" -> 3, "DataRowCount" -> 2, "DataColumnCount" -> 
       3, "SortPaths" -> {}, "SortDirections" -> {}, "HiddenItemsMap" -> Null,
        "UpdateType" -> 1|>, TypeSystem`NestedGrid`PackagePrivate`$outputID$$,
       TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
      TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
      DynamicModule[{
       TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
          Style[
           Grid[{{
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL1", 
                    Style[
                    "COL1", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL1"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL1"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}], 
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL2", 
                    Style[
                    "COL2", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL2"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL2"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}], 
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL3", 
                    Style[
                    "COL3", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL3"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL3"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}]}, {
              Item[
               Pane[
                Annotation[
                 RawBoxes["1.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL1"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["2.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL2"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["3.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL3"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}]}, {
              Item[
               Pane[
                Annotation[
                 RawBoxes["4.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL1"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["5.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL2"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["6.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL3"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}]}}, 
            BaseStyle -> {
             ContextMenu -> 
              Dynamic[TypeSystem`NestedGrid`PackagePrivate`$\
contextMenuTrigger; 
                Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                  TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                  TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger, TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu,
                   True, TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger = 
                   TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                  TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                   Block[{TypeSystem`NestedGrid`PackagePrivate`$\
globalScrollPos = {TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                    
                    With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    "Show " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    "Hide " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], Nothing]}]]]]], FontFamily -> 
              "Source Sans Pro", FontSize -> 14, FontWeight -> Plain}, 
            Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
            Spacings -> {0, 0}, Alignment -> Left, 
            BaseStyle -> {
             FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
              Plain}], LineBreakWithin -> False, ContextMenu -> {}, 
           NumberMarks -> False, ShowAutoStyles -> False]], 
        TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
       Dynamic[
        TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
        TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
           Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
           
           Module[{TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
             TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
             TypeSystem`NestedGrid`PackagePrivate`datasetData[
              TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
               FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
               TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
               TypeSystem`NestedGrid`PackagePrivate`renderGrid[
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
               TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
              Not[
               FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
              TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
              TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
         TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
         TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
         TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
           FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
           TypeSystem`SparseGrid[
            TypeSystem`H["(data no longer present)"]], 
           TypeSystem`NestedGrid`PackagePrivate`renderedGrid]], 
        TrackedSymbols :> {
         TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
       DynamicModuleValues :> {}], 
      TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
       TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
        TypeSystem`PackageScope`SubViewPathbar[
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
         TypeSystem`NestedGrid`PackagePrivate`updateState[
         TypeSystem`NestedGrid`PackagePrivate`$state$$, 
          TypeSystem`NestedGrid`PackagePrivate`$path$$, 
          TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
       TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
      TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
       Framed[
        Dynamic[
         Replace[
         TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
          TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
             Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
              Blank[]], 
             Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
              Blank[]], 
             Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
              Blank[]]] :> (
            Increment[
             TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
             TypeSystem`NestedGrid`PackagePrivate`path$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
             TypeSystem`NestedGrid`PackagePrivate`pathType$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
             TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
             TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
            TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
             TypeSystem`NestedGrid`PackagePrivate`path$, 
              TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
           Spacer[10], Blank[] :> Spacer[10]}], 
         TrackedSymbols :> {
          TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], 
        FrameStyle -> None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> 
        Top, ImageSize -> {Automatic, 15}], FontSize -> 1], 
      TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
      DynamicWrapperBox[
       DynamicBox[ToBoxes[
         Dataset`DatasetContent[
         2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
          "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], 
          "State" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], 
          "VPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], 
          "HPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], 
          "TopBar" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], 
          "BottomBar" -> 
          Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
          Hold[
            TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
        ImageSizeCache->{206., {41.45765625, 57.54234375}},
        TrackedSymbols:>{
         TypeSystem`NestedGrid`PackagePrivate`$state$$, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
       MouseAnnotation[],
       ImageSizeCache->{206., {41.45765625, 57.54234375}}],
      BaseStyle->{LineBreakWithin -> False},
      DynamicModuleValues:>{},
      Initialization:>(TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = 
       CreateUUID[]),
      UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
     Deploy,
     DefaultBaseStyle->"Deploy"],
    Dataset`InterpretDataset[1],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   RowBox[{"\"\<ColumnDescriptions\>\"", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<COL1\>\"", "->", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{"\"\<Name\>\"", "\[Rule]", "\"\<A\>\""}], 
        "\[RightAssociation]"}]}], ",", 
      RowBox[{"3", "->", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{"\"\<Name\>\"", "\[Rule]", "\"\<C\>\""}], 
        "\[RightAssociation]"}]}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843130592659457*^9, 3.843130625334804*^9}, {
  3.843130722645812*^9, 3.843130744076643*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"a562a10d-d979-4572-8933-592a123a1ee7"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", 
   TagBox[
    TagBox[
     DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = <|
      "InitialData" -> {<|"COL1" -> 1., "COL2" -> 2., "COL3" -> 3.|>, <|
         "COL1" -> 4., "COL2" -> 5., "COL3" -> 6.|>}, "AllowEmbedding" -> 
       True, "InitialShape" -> 
       TypeSystem`PackageScope`HeaderShape[<|{All, "COL1"} -> 
          1, {All, "COL2"} -> 1, {All, "COL3"} -> 1|>, 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`Limited[
            
            TypeSystem`PackageScope`RowShape[<|
             "COL1" -> TypeSystem`PackageScope`AtomShape[60], "COL2" -> 
              TypeSystem`PackageScope`AtomShape[60], "COL3" -> 
              TypeSystem`PackageScope`AtomShape[60]|>], 
            DirectedInfinity[1], 3, {All}]], 2, 
          DirectedInfinity[1], {}]], "InitialType" -> TypeSystem`Vector[
         TypeSystem`Struct[{"COL1", "COL2", "COL3"}, {
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real]}], 2], "Meta" -> <||>, "RowTarget" -> 20, 
       "ColumnTarget" -> 10, "Shape" -> 
       TypeSystem`PackageScope`HeaderShape[<|{All, "COL1"} -> 
          1, {All, "COL2"} -> 1, {All, "COL3"} -> 1|>, 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`Limited[
            
            TypeSystem`PackageScope`RowShape[<|
             "COL1" -> TypeSystem`PackageScope`AtomShape[60], "COL2" -> 
              TypeSystem`PackageScope`AtomShape[60], "COL3" -> 
              TypeSystem`PackageScope`AtomShape[60]|>], 
            DirectedInfinity[1], 3, {All}]], 2, 
          DirectedInfinity[1], {}]], "Type" -> TypeSystem`Vector[
         TypeSystem`Struct[{"COL1", "COL2", "COL3"}, {
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real], 
           TypeSystem`Atom[Real]}], 2], "Path" -> {}, "DisplayedRowCount" -> 
       2, "DisplayedColumnCount" -> 3, "DataRowCount" -> 2, "DataColumnCount" -> 
       3, "SortPaths" -> {}, "SortDirections" -> {}, "HiddenItemsMap" -> Null,
        "UpdateType" -> 1|>, TypeSystem`NestedGrid`PackagePrivate`$outputID$$,
       TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
      TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
      DynamicModule[{
       TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
          Style[
           Grid[{{
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL1", 
                    Style[
                    "COL1", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL1"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL1"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}], 
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL2", 
                    Style[
                    "COL2", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL2"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL2"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}], 
              Item[
               Pane[
                Annotation[
                 EventHandler[
                  MouseAppearance[
                   Mouseover["COL3", 
                    Style[
                    "COL3", FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                  If[
                    TypeSystem`NestedGrid`PackagePrivate`checkInteractivity[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                    All, "COL3"}, 1]]], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                  All, "COL3"}, "ColumnHeader", True], "Mouse"], 
                ImageSize -> {{1, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
               GrayLevel[0.95], Alignment -> {Left, Baseline}]}, {
              Item[
               Pane[
                Annotation[
                 RawBoxes["1.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL1"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["2.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL2"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["3.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                   Key["COL3"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}]}, {
              Item[
               Pane[
                Annotation[
                 RawBoxes["4.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL1"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["5.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL2"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}], 
              Item[
               Pane[
                Annotation[
                 RawBoxes["6.0"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                  TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                   Key["COL3"]}, "Item", False], "Mouse"], 
                ImageSize -> {{60, Full}, Automatic}, 
                ImageMargins -> {{5, 3}, {4, 5}}], 
               ItemSize -> {Full, Automatic}]}}, 
            BaseStyle -> {
             ContextMenu -> 
              Dynamic[TypeSystem`NestedGrid`PackagePrivate`$\
contextMenuTrigger; 
                Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                  TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                  TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger, TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu,
                   True, TypeSystem`NestedGrid`PackagePrivate`$\
lastContextMenuTrigger = 
                   TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                  TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                   Block[{TypeSystem`NestedGrid`PackagePrivate`$\
globalScrollPos = {TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                    
                    With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    "Show " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    "Hide " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], Nothing]}]]]]], FontFamily -> 
              "Source Sans Pro", FontSize -> 14, FontWeight -> Plain}, 
            Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
            Spacings -> {0, 0}, Alignment -> Left, 
            BaseStyle -> {
             FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
              Plain}], LineBreakWithin -> False, ContextMenu -> {}, 
           NumberMarks -> False, ShowAutoStyles -> False]], 
        TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
       Dynamic[
        TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
        TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
           Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
           
           Module[{TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
             TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
             TypeSystem`NestedGrid`PackagePrivate`datasetData[
              TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
               FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
               TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
               TypeSystem`NestedGrid`PackagePrivate`renderGrid[
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
               TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
              Not[
               FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
              TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
              TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
         TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
         TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
         TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
           FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
           TypeSystem`SparseGrid[
            TypeSystem`H["(data no longer present)"]], 
           TypeSystem`NestedGrid`PackagePrivate`renderedGrid]], 
        TrackedSymbols :> {
         TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
       DynamicModuleValues :> {}], 
      TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
       TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
        TypeSystem`PackageScope`SubViewPathbar[
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
         TypeSystem`NestedGrid`PackagePrivate`updateState[
         TypeSystem`NestedGrid`PackagePrivate`$state$$, 
          TypeSystem`NestedGrid`PackagePrivate`$path$$, 
          TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
       TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
      TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
       Framed[
        Dynamic[
         Replace[
         TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
          TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
             Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
              Blank[]], 
             Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
              Blank[]], 
             Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
              Blank[]]] :> (
            Increment[
             TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
             TypeSystem`NestedGrid`PackagePrivate`path$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
             TypeSystem`NestedGrid`PackagePrivate`pathType$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
             TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
            TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
             TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
            TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
             TypeSystem`NestedGrid`PackagePrivate`path$, 
              TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
           Spacer[10], Blank[] :> Spacer[10]}], 
         TrackedSymbols :> {
          TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], 
        FrameStyle -> None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> 
        Top, ImageSize -> {Automatic, 15}], FontSize -> 1], 
      TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
      DynamicWrapperBox[
       DynamicBox[ToBoxes[
         Dataset`DatasetContent[
         2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
          "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], 
          "State" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], 
          "VPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], 
          "HPos" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], 
          "TopBar" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], 
          "BottomBar" -> 
          Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
          Hold[
            TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
        ImageSizeCache->{206., {41.45765625, 57.54234375}},
        TrackedSymbols:>{
         TypeSystem`NestedGrid`PackagePrivate`$state$$, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
       MouseAnnotation[],
       ImageSizeCache->{206., {41.45765625, 57.54234375}}],
      BaseStyle->{LineBreakWithin -> False},
      DynamicModuleValues:>{},
      Initialization:>(TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = 
       CreateUUID[]),
      UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
     Deploy,
     DefaultBaseStyle->"Deploy"],
    Dataset`InterpretDataset[1],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   RowBox[{"\"\<ColumnDescriptions\>\"", "->", 
    RowBox[{"<|", 
     RowBox[{
      RowBox[{"\"\<COL1\>\"", "->", 
       RowBox[{"\[LeftAssociation]", 
        RowBox[{"\"\<Name\>\"", "\[Rule]", "\"\<A\>\""}], 
        "\[RightAssociation]"}]}], ",", 
      RowBox[{"3", "->", "\"\<C\>\""}]}], "|>"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843130759732521*^9, 3.843130824362588*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"945cf3bd-254d-4afe-a189-4a450799bea7"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.dta\>\"", ",", "\"\<ColumnDescriptions\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843130630950301*^9, 3.843130633020446*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"b0bdd946-8ceb-4f6b-852b-73875e71ee31"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"fb1d229e-4f05-43ff-ba6b-7eedb3e0b0b2"],

Cell[CellGroupData[{

Cell["NetCDF", "Section",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, 
   3.7880179920575123`*^9, {3.843061873704077*^9, 
   3.843061877128853*^9}},ExpressionUUID->"f9102330-02a2-4f44-954f-\
2c22f3d4059d"],

Cell[CellGroupData[{

Cell["Basic Updates", "Subsection",
 CellChangeTimes->{{3.8430685252217493`*^9, 
  3.8430685264701233`*^9}},ExpressionUUID->"94433b83-8744-4c30-a97d-\
0e8d50b96015"],

Cell[CellGroupData[{

Cell["\<\
Import got a total overhaul, getting a new backend and extended support\
\>", "Item",
 CellChangeTimes->{{3.843068529021961*^9, 
  3.843068552737199*^9}},ExpressionUUID->"0d17a0c2-0a35-40ae-a3b1-\
2492d873cf77"],

Cell["\<\
Now NetCDF v4 is supported in addition to the already supported v3\
\>", "Item",
 CellChangeTimes->{{3.843068529021961*^9, 
  3.8430685653692102`*^9}},ExpressionUUID->"a7688235-4462-4ea5-866a-\
54fcd77a5c10"],

Cell["New convenient notation to Import a specific dataset:", "Item",
 CellChangeTimes->{{3.843041778093801*^9, 3.843041818099193*^9}, {
  3.843042022029134*^9, 3.843042037165105*^9}, {3.843042097278906*^9, 
  3.843042167023519*^9}},ExpressionUUID->"3d0f2da8-7154-4dba-bc84-\
e72b8a3b8aa3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Import", "[", " ", 
  RowBox[{"\"\<ExampleData/precipitation.nc\>\"", ",", "\"\</ANOMALY\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8430421722086687`*^9, 3.843042173585861*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"07cc6131-902d-4223-be1f-69122bacb5cf"]
}, Closed]],

Cell[CellGroupData[{

Cell["New Structure", "Subsection",
 CellChangeTimes->{{3.8430684498195972`*^9, 3.843068469658924*^9}, 
   3.843068500317568*^9},ExpressionUUID->"05a8af4e-ec8e-4bad-980f-\
9ef10c26e728"],

Cell["Moving towards Associations for structured data", "Text",
 CellChangeTimes->{{3.843068578842904*^9, 
  3.843068585491436*^9}},ExpressionUUID->"84214557-791c-4daa-8bd8-\
886d400f827b"],

Cell["In 12.3:", "Item",
 CellChangeTimes->{{3.843068486280635*^9, 
  3.843068490326902*^9}},ExpressionUUID->"67bab06a-1b30-47ec-8eb3-\
02d8344d4947"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3Qe8LUV9OHAJSAiGYImJqUaBxJgmaZqqmGjUWP/GxJh8ko8lAUWKiBRp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    "], {{0, 480.}, {1453., 0}}, {0, 255},
    ColorFunction->RGBColor,
    ImageResolution->{144., 144.},
    SmoothingQuality->"High"],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{1453., 480.},
  PlotRange->{{0, 1453.}, {0, 480.}}]], "Input",ExpressionUUID->"1cdc70d2-\
fe3a-471e-9bcd-e5baa4881611"],

Cell["In 13.0:", "Item",
 CellChangeTimes->{{3.8430684808692207`*^9, 
  3.84306848239469*^9}},ExpressionUUID->"9d7829d8-bdf9-4c35-96d2-\
0e5803e8c3d6"],

Cell[BoxData[
 RowBox[{"Import", "[", " ", 
  RowBox[{"\"\<ExampleData/precipitation.nc\>\"", ",", "\"\<Dimensions\>\""}],
   "]"}]], "Input",
 CellChangeTimes->{{3.843041915187065*^9, 3.843041958302252*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"7ad7d03d-29ec-4353-a389-79afbc72d64b"],

Cell[BoxData[
 RowBox[{"Import", "[", " ", 
  RowBox[{"\"\<ExampleData/precipitation.nc\>\"", ",", "\"\<Metadata\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843042694548421*^9, 3.843042695780631*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"63a64b00-aaf4-403a-ab0d-895613193b4a"],

Cell[CellGroupData[{

Cell["\<\
Numerical data now comes in NumericArrays for increased performance:\
\>", "Item",
 CellChangeTimes->{{3.843041778093801*^9, 3.843041818099193*^9}, {
  3.843042022029134*^9, 3.843042037165105*^9}, {3.843042097278906*^9, 
  3.843042127667378*^9}},ExpressionUUID->"41028d98-47c2-4a7e-bf97-\
8a9970895bbc"],

Cell[BoxData[
 RowBox[{"Import", "[", " ", 
  RowBox[{"\"\<ExampleData/precipitation.nc\>\"", ",", "\"\<Data\>\""}], 
  "]"}]], "Input",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15000.},
 CellChangeTimes->{{3.843042133136735*^9, 3.843042133487054*^9}},
 CellLabel->
  "In[139]:=",ExpressionUUID->"a3d94ee7-368e-4b90-9b50-a250856b689f"],

Cell["\<\
Dimensions now treated as first-class citizens, not just a property of \
datasets:\
\>", "Item",
 CellChangeTimes->{{3.843041778093801*^9, 3.843041818099193*^9}, {
  3.843042022029134*^9, 3.843042037165105*^9}, {3.843042097278906*^9, 
  3.843042167023519*^9}, {3.843042202272053*^9, 
  3.8430422613120823`*^9}},ExpressionUUID->"030c5a2a-8b7d-4c96-84c8-\
00c57beff5a1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", " ", 
   RowBox[{
   "\"\<ExampleData/precipitation.nc\>\"", ",", "\"\<DimensionNames\>\""}], 
   "]"}], "//", "Dataset"}]], "Input",
 CellChangeTimes->{{3.843131215930352*^9, 3.84313121792303*^9}},
 CellLabel->
  "In[151]:=",ExpressionUUID->"02b02fdf-31e1-4f03-a154-016fbbe3729f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", " ", 
   RowBox[{
   "\"\<ExampleData/precipitation.nc\>\"", ",", "\"\<NamedDimensions\>\""}], 
   "]"}], "//", "Dataset"}]], "Input",
 CellChangeTimes->{{3.8430421722086687`*^9, 3.843042173585861*^9}, {
   3.843042268162623*^9, 3.8430422805785217`*^9}, {3.8431310322932177`*^9, 
   3.843131033036771*^9}, 3.843131089647052*^9},
 CellLabel->
  "In[140]:=",ExpressionUUID->"090d2991-ffe3-4eea-beff-622185bc466a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", " ", 
   RowBox[{
   "\"\<ExampleData/precipitation.nc\>\"", ",", "\"\<DataFormat\>\""}], "]"}],
   "//", "Dataset"}]], "Input",
 CellChangeTimes->{{3.843131383190446*^9, 3.8431313841651163`*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"e6b890f0-8941-42ac-ad3e-a3d1afdc4873"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<test_vlen3.nc\>\""}], 
   ",", "\"\<Data\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.8431311102817297`*^9, 3.843131133266411*^9}},
 CellLabel->
  "In[150]:=",ExpressionUUID->"c5bcbb6f-7253-4bcd-a233-7f099b59328b"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<test_vlen3.nc\>\""}], 
   ",", "\"\<DataFormat\>\""}], "]"}]], "Input",
 CellLabel->
  "In[146]:=",ExpressionUUID->"d20e8a26-7d0a-473a-8dbc-a37865caf241"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<test_vlen3.nc\>\""}],
     ",", "\"\<DataFormat\>\""}], "]"}], "//", "Dataset"}]], "Input",
 CellChangeTimes->{{3.843073277691793*^9, 3.8430732912220163`*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"cf3b0bf8-33d2-4c40-9ec5-fd7c40818979"]
}, Closed]],

Cell[CellGroupData[{

Cell["For Advanced Users", "Subsection",
 CellChangeTimes->{{3.843073326508683*^9, 
  3.8430733304425488`*^9}},ExpressionUUID->"d247fcf2-1e76-4774-9515-\
830887f1bb26"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<test_vlen3.nc\>\""}], 
   ",", "\"\<DataFormatLegacy\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843042805558138*^9, 3.843042808309154*^9}, 
   3.8430733461355677`*^9},
 CellLabel->
  "In[154]:=",ExpressionUUID->"b5e20b74-33de-40d9-a870-80fccfde4931"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<test_vlen3.nc\>\""}], 
   ",", "\"\<DataLegacy\>\""}], "]"}]], "Input",
 CellChangeTimes->{3.843042910899493*^9, 3.843073348479895*^9},
 CellLabel->
  "In[155]:=",ExpressionUUID->"40c27140-00db-49bf-8f2e-e5982f3adbb6"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"20d3af15-f3ae-4b4a-b9ae-9d4bbf712881"],

Cell[CellGroupData[{

Cell["MBOX Threads", "Section",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, 
   3.7880179920575123`*^9, {3.843061873704077*^9, 3.843061877128853*^9}, {
   3.843061931759432*^9, 
   3.843061936542934*^9}},ExpressionUUID->"fb032533-9e15-4ad9-9c11-\
cf8b37caba6a"],

Cell[CellGroupData[{

Cell["Thread Elements", "Subsection",
 CellChangeTimes->{{3.8430720743837442`*^9, 3.843072075879861*^9}, {
  3.843130360536489*^9, 
  3.8431303615755377`*^9}},ExpressionUUID->"92eeb66d-3c21-4719-8069-\
c50e22f936bd"],

Cell["\<\
Data source: \
https://lists.apache.org/list.html?user@forrest.apache.org:2005-12\
\>", "Text",
 CellChangeTimes->{{3.8430686978157454`*^9, 
  3.843068706515588*^9}},ExpressionUUID->"98e44468-7f7c-4777-8e4d-\
fe7fd190da10"],

Cell[BoxData[
 RowBox[{
  RowBox[{"file", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<user_forrest_apache_org_2005-12.mbox\>\""}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.843068709703561*^9, 3.843068751133973*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"22572d49-3106-4caf-9aff-587f6a8f26a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"labels", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"#MessageID", "->", 
      RowBox[{"Placed", "[", 
       RowBox[{"#BodyPreview", ",", "Tooltip"}], "]"}]}], "&"}], "/@", 
    RowBox[{"Import", "[", 
     RowBox[{"file", ",", "\"\<MessageSummary\>\""}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.843068763546516*^9, 3.843068769031624*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"4bb1ee03-270f-4e26-b671-00589bcc0577"],

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"file", ",", "\"\<ThreadGraph\>\""}], "]"}], ",", 
   RowBox[{"VertexLabels", "->", "labels"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843068763546516*^9, 3.843068769031624*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"7bec33e2-e564-4c72-8136-f86d3f295b71"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"file", ",", "\"\<ThreadCount\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.8430711630034122`*^9, 3.843071164020528*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"03a70506-1529-4750-baee-81099ec00b3e"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"file", ",", "\"\<ThreadEmailCount\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.8430711630034122`*^9, 3.843071181195722*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"55f1c796-aa1f-4e44-81c5-906d4b38939f"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"file", ",", "\"\<ThreadTimeInterval\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843071196562662*^9, 3.843071198586234*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"68245f65-a9f9-43df-ad59-c1f05a624e29"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"file", ",", "\"\<ThreadDuration\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843071205555233*^9, 3.843071207218833*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"d6885c86-11b9-4edf-b911-7d5461353fcd"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"file", ",", "\"\<ThreadMessageIDList\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.8430712162524137`*^9, 3.843071228377656*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"f70d8f58-328e-49f7-94b8-36810df54ef4"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"file", ",", "\"\<ThreadFromList\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843071237027866*^9, 3.84307126050786*^9}},
 CellLabel->
  "In[164]:=",ExpressionUUID->"8453ac88-dd61-4b71-b7ed-d5a8f9741429"],

Cell[BoxData[
 RowBox[{
  RowBox[{"labels", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"#MessageID", "->", 
      RowBox[{"Placed", "[", 
       RowBox[{"#Body", ",", "Tooltip"}], "]"}]}], "&"}], "/@", 
    RowBox[{"Import", "[", 
     RowBox[{
     "\"\<ExampleData/conv.mbox\>\"", ",", "\"\<MessageElements\>\""}], 
     "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.843071470902378*^9, {3.843071506702155*^9, 3.8430715267969713`*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"c1ec9ce7-6a1e-4e56-987c-aa4046284a7f"],

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\<ExampleData/conv.mbox\>\"", ",", "\"\<ReferenceMessageIDGraph\>\""}],
     "]"}], ",", 
   RowBox[{"VertexLabels", "->", "labels"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843071265977112*^9, 3.843071410239887*^9}, {
  3.843071491811659*^9, 3.8430714928569736`*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"40764ba5-6208-42ed-9cc0-834943bb78a7"],

Cell[BoxData[
 RowBox[{"TransitiveClosureGraph", "@", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<ExampleData/conv.mbox\>\"", ",", "\"\<ThreadGraph\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.843071544107502*^9, 3.843071549091198*^9}},
 CellLabel->
  "In[168]:=",ExpressionUUID->"bf9e2ce1-477c-4b07-8cb9-34aad0853b5a"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"ee72f595-b7a5-4406-9840-45a929451f5d"],

Cell[CellGroupData[{

Cell["New Import/Export framework metadata functions", "Section",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, 
   3.7880179920575123`*^9, {3.843061873704077*^9, 3.843061877128853*^9}, {
   3.843061944966982*^9, 
   3.843061956110862*^9}},ExpressionUUID->"5234083a-e6d4-4181-9c3a-\
0d08c04cbf2d"],

Cell[BoxData[
 TemplateBox[{
  "\"paclet:tutorial/ImportingAndExporting\"", 
   "paclet:tutorial/ImportingAndExporting"},
  "HyperlinkPaclet"]], "Output",
 CellChangeTimes->{
  3.843126102956098*^9, {3.8431261642297993`*^9, 3.843126177749035*^9}},
 CellLabel->"Out[28]=",ExpressionUUID->"6e5c6120-603e-4197-b69c-88f322a55619"],

Cell[CellGroupData[{

Cell["(Set)FileFormatProperties", "Subsection",
 CellChangeTimes->{{3.843125724430627*^9, 3.843125733790238*^9}, {
  3.843126072495822*^9, 
  3.843126073535634*^9}},ExpressionUUID->"a32bcbef-6de5-4cba-b9be-\
88122ec4796e"],

Cell["FileFormatProperties", "Item",
 CellChangeTimes->{{3.843071933931993*^9, 
  3.84307193718016*^9}},ExpressionUUID->"986791e9-ea5f-4be3-9fca-\
0f3611c3e843"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FileFormatProperties", "[", "]"}], "[", 
  RowBox[{"[", 
   RowBox[{";;", "5"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.843071717961337*^9, 3.843071748830908*^9}, {
  3.843071786003181*^9, 3.8430717903781633`*^9}},
 CellLabel->
  "In[169]:=",ExpressionUUID->"04c86c75-6e04-43c6-83d9-26d3645bfeaf"],

Cell[BoxData[
 RowBox[{"FileFormatProperties", "[", "\"\<CSV\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.8430717973714542`*^9, 3.8430717985298357`*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"d6b92618-ca39-48cd-a11b-65d1a5777218"],

Cell[BoxData[
 RowBox[{"ImportString", "[", 
  RowBox[{"\"\<1,2,3\\n4,5,6\\n7,8,9\>\"", ",", "\"\<CSV\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843071820586369*^9, 3.8430718368168573`*^9}, {
  3.843071891773897*^9, 3.843071907885436*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"409775cf-e8ff-47fb-91ee-f8a67c43d623"],

Cell[BoxData[
 RowBox[{"SetFileFormatProperties", "[", 
  RowBox[{"\"\<CSV\>\"", ",", 
   RowBox[{"\"\<DefaultImportElement\>\"", "->", "\"\<Dataset\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843071802657292*^9, 3.843071819233719*^9}, {
  3.8430719101275387`*^9, 3.8430719102278852`*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"b7c4b013-5b9c-417d-9987-83e67161a51b"],

Cell[BoxData[
 RowBox[{"ImportString", "[", 
  RowBox[{"\"\<1,2,3\\n4,5,6\\n7,8,9\>\"", ",", "\"\<CSV\>\""}], 
  "]"}]], "Input",
 CellLabel->
  "In[173]:=",ExpressionUUID->"5e62f92a-ef4c-467f-b1ed-ca3f72306037"],

Cell[BoxData[
 RowBox[{"FileFormatProperties", "[", 
  RowBox[{"\"\<CSV\>\"", ",", "\"\<Properties\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843071951923232*^9, 3.843071952994997*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"60e43aa3-abbf-4557-a4ca-70e8627241d2"],

Cell[BoxData[
 RowBox[{"FileFormatProperties", "[", 
  RowBox[{"\"\<CSV\>\"", ",", "\"\<ImportElements\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.843071942955977*^9, 3.843071964234888*^9}},
 CellLabel->
  "In[175]:=",ExpressionUUID->"f14980a4-d1c8-45e8-81f2-d1def83bb7c0"],

Cell[BoxData[
 RowBox[{"FileFormatProperties", "[", 
  RowBox[{"\"\<CSV\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<MIMETypes\>\"", ",", "\"\<FileNamePatterns\>\""}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8430719660990353`*^9, 3.843071971123569*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"ab45a5ce-7b8a-43a2-bc24-427beaba2db7"]
}, Closed]],

Cell[CellGroupData[{

Cell["FileNameToFormatList", "Subsection",
 CellChangeTimes->{{3.8431257406060534`*^9, 
  3.843125742894163*^9}},ExpressionUUID->"0ca39841-31dc-4eda-85b0-\
750e251d0fc4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FileNameToFormatList", "[", "]"}], "//", "Short"}]], "Input",
 CellChangeTimes->{{3.843071973757456*^9, 3.8430719792986803`*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"a6218883-a7ad-4feb-bfd4-625994dfde80"],

Cell[BoxData[
 RowBox[{"FileNameToFormatList", "[", "\"\<foo.cdf\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.8430719856358356`*^9, 3.843071994282332*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"45cd8581-c52b-4001-88da-9e0fb460c7c5"]
}, Closed]],

Cell[CellGroupData[{

Cell["MIMETypeToFormatList", "Subsection",
 CellChangeTimes->{{3.843125745109785*^9, 
  3.843125751430004*^9}},ExpressionUUID->"64e7630e-e4a0-40e1-ab98-\
c0e862e0bc8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MIMETypeToFormatList", "[", "]"}], "//", "Short"}]], "Input",
 CellChangeTimes->{3.8431258634389973`*^9},
 CellLabel->
  "In[179]:=",ExpressionUUID->"9bf064bc-30f7-47b9-880a-50b05ab35e5a"],

Cell[BoxData[
 RowBox[{"MIMETypeToFormatList", "[", "\"\<text/csv\>\"", "]"}]], "Input",
 CellChangeTimes->{3.843125769438602*^9},
 CellLabel->
  "In[180]:=",ExpressionUUID->"884a7ef0-afb8-41ee-98f4-0bba34a26e4e"],

Cell[BoxData[
 RowBox[{"MIMETypeToFormatList", "[", 
  RowBox[{"\"\<video/\>\"", "~~", "__"}], "]"}]], "Input",
 CellChangeTimes->{{3.843071999514016*^9, 3.8430720217464037`*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"75785077-8cc0-435a-ad8a-eee8e8f0e575"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"966b4952-2666-4de3-9597-e79d88e4d035"],

Cell[CellGroupData[{

Cell["Format Updates", "Section",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, 
   3.7880179920575123`*^9, {3.843061873704077*^9, 
   3.843061913102796*^9}},ExpressionUUID->"bb2d9296-607e-4543-a96d-\
ff70c4aa835c"],

Cell[CellGroupData[{

Cell["PDF", "Subsection",
 CellChangeTimes->{{3.8430631584886713`*^9, 
  3.843063160744597*^9}},ExpressionUUID->"f2659b91-a3ef-4e50-a6c4-\
70611f561549"],

Cell[BoxData[
 RowBox[{
  RowBox[{"URLDownload", "[", 
   RowBox[{
   "\"\<http://exampledata.wolfram.com/article.pdf\>\"", ",", 
    "\"\<article.pdf\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.843071650064105*^9, 3.843071661108574*^9}},
 CellLabel->
  "In[182]:=",ExpressionUUID->"a2b1075b-1b86-4487-bbe7-7ff27d324531"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<article.pdf\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<PageImages\>\"", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843071650064105*^9, 3.843071661108574*^9}},
 CellLabel->
  "In[183]:=",ExpressionUUID->"d7414e1c-6151-4a4f-bfda-6bedb8b061cf"],

Cell[BoxData[
 RowBox[{"Head", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.843071684691312*^9, 3.843071686524802*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"0af881bd-f66e-495c-aa24-9010a6d3f9f8"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<article.pdf\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<PageGraphics\>\"", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.843071650064105*^9, 3.843071670985408*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"801d1519-a7c5-4117-8e25-125e1fba23dc"],

Cell[BoxData[
 RowBox[{"Head", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.8430716899064817`*^9, 3.8430716919444437`*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"128195d6-c4be-49fc-a337-18b4535a5956"]
}, Closed]],

Cell[CellGroupData[{

Cell["Image Formats", "Subsection",
 CellChangeTimes->{{3.843063164000579*^9, 3.843063166320347*^9}, {
  3.843123793271545*^9, 
  3.843123807553863*^9}},ExpressionUUID->"9ff6d0f7-f9d4-4716-9a0e-\
17c12606d315"],

Cell[CellGroupData[{

Cell["WebP", "Subsubsection",
 CellChangeTimes->{{3.843117226643733*^9, 
  3.84311722758393*^9}},ExpressionUUID->"541bc338-309f-4b63-9b51-\
2ca0fa1dc93c"],

Cell["We now support import and export of animated WebP:", "Item",
 CellChangeTimes->{{3.843123816936857*^9, 
  3.843123819600923*^9}},ExpressionUUID->"0b13af1d-337e-4a70-8d3d-\
8234b7e9d2fe"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.webp\>\"", ",", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ConstantImage", "[", 
       RowBox[{"RandomColor", "[", "]"}], "]"}], ",", " ", "5"}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"%", ",", " ", "\"\<AnimatedImage\>\"", ",", " ", 
   RowBox[{"AnimationRepetitions", " ", "->", " ", "Infinity"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.8431172524775333`*^9, 3.843117311553604*^9}, {
  3.8431173513429737`*^9, 3.843117352640033*^9}},
 CellLabel->
  "In[187]:=",ExpressionUUID->"d37bf2fd-281e-40f6-89e1-3ad156c64ded"],

Cell["\<\
Export is optimizes the animations adjusting the duplications:\
\>", "Item",
 CellChangeTimes->{{3.843123823138475*^9, 
  3.843123838169771*^9}},ExpressionUUID->"49484571-95c2-4428-8de7-\
c4db6d2fa19d"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.webp\>\"", ",", " ", "\"\<DisplayDurations\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843117342727728*^9, 3.843117375455617*^9}},
 CellLabel->
  "In[189]:=",ExpressionUUID->"09307db1-b350-4100-929d-5a88dee0c42e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.webp\>\"", ",", " ", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{
        RowBox[{"RandomImage", "[", "]"}], ",", " ", "10"}], "]"}], ",", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"RandomImage", "[", "]"}], ",", " ", "3"}], "]"}]}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"%", ",", " ", "\"\<DisplayDurations\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.84311737728716*^9, 3.843117420762946*^9}},
 CellLabel->
  "In[190]:=",ExpressionUUID->"4196d367-c430-483d-96e3-2311411d02c8"],

Cell["We now support Exif and XMP:", "Item",
 CellChangeTimes->{{3.8431239131021976`*^9, 
  3.843123915662537*^9}},ExpressionUUID->"a1f6b087-9124-4445-a9f1-\
94a531e4e456"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", " ", "=", " ", 
   RowBox[{"Import", "[", "\"\<ExampleData/coneflower.jpg\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Keys", "[", 
  RowBox[{"MetaInformation", "/.", 
   RowBox[{"Options", "[", "i", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.84310963511672*^9, 3.8431096576963463`*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"1e9f9edd-f3a3-46e5-8aaa-f588ef9adb7e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.webp\>\"", ",", " ", "i"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Keys", "[", 
  RowBox[{"MetaInformation", "/.", 
   RowBox[{"Options", "[", 
    RowBox[{"Import", "[", "%", "]"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.843109661101424*^9, 3.843109690598331*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"a738c2c6-e3c1-498d-8542-bfb72b0f4985"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<test.webp\>\"", ",", " ", 
     RowBox[{"RandomImage", "[", "]"}]}], "]"}], ",", " ", "\"\<Exif\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.843116724955917*^9, 3.843116736209406*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"0e41c7f1-e9cd-4611-a888-4c89a85d1f1c"]
}, Closed]],

Cell[CellGroupData[{

Cell["HEIF", "Subsubsection",
 CellChangeTimes->{{3.843124095564189*^9, 
  3.843124096075252*^9}},ExpressionUUID->"aa326e3e-0daf-4fc4-a1c8-\
6ac53a3823fa"],

Cell["We support export of Mac:", "Text",
 CellChangeTimes->{{3.843117439501059*^9, 
  3.843117443259*^9}},ExpressionUUID->"82d7a31a-84e2-4aec-9816-c870a483d61e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.heic\>\"", ",", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ConstantImage", "[", 
       RowBox[{"RandomColor", "[", "]"}], "]"}], ",", " ", "5"}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"%", ",", " ", "\"\<AnimatedImage\>\"", ",", " ", 
   RowBox[{"AnimationRepetitions", " ", "->", " ", "Infinity"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.843117447134231*^9, 3.8431174664508753`*^9}},
 CellLabel->
  "In[197]:=",ExpressionUUID->"a4c07aa0-936a-420a-a679-e5c5d96c23f2"]
}, Closed]],

Cell[CellGroupData[{

Cell["OpenEXR", "Subsubsection",
 CellChangeTimes->{{3.843124102524198*^9, 
  3.843124105435659*^9}},ExpressionUUID->"ed876217-607c-4947-8ef2-\
6fbd65a9aa5e"],

Cell[CellGroupData[{

Cell["\<\
We now fully support all modes of OpenEXR (including multi-part and \
multi-view) import and export:\
\>", "Item",
 CellChangeTimes->{{3.8431241531038437`*^9, 3.843124155516253*^9}, {
  3.843129310929102*^9, 
  3.8431293125301723`*^9}},ExpressionUUID->"b2588e95-711f-45f1-b066-\
04b238e273b5"],

Cell[CellGroupData[{

Cell["Scanline", "Subitem",
 CellChangeTimes->{{3.84311758389009*^9, 
  3.843117585151844*^9}},ExpressionUUID->"d9428bf0-374e-43c7-a576-\
36e387959a49"],

Cell[BoxData[{
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.exr\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RandomImage", "[", "]"}], ",", 
     RowBox[{"RandomImage", "[", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.exr\>\"", ",", "\"\<Summary\>\""}], "]"}]}], "Input",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.},
 CellChangeTimes->{{3.843117693818781*^9, 3.843117696528247*^9}, {
  3.843128954163535*^9, 3.8431289863179092`*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"5d85d0f2-4cef-4385-a117-61e4ee3c4a29"],

Cell["Mipmap", "Subitem",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.},
 CellChangeTimes->{{3.84311758389009*^9, 
  3.843117590783388*^9}},ExpressionUUID->"cbfd2387-7f6a-40a4-b99d-\
72752f86bd99"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", " ", "=", " ", 
   RowBox[{"FindFile", "@", "\"\<ExampleData/PeriodicPattern.exr\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ii", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"f", ",", " ", "\"\<ChannelImageList\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", "ii", ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<Mipmap\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"iiN", " ", "=", " ", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", "\"\<ChannelImageList\>\""}], 
   "]"}]}]}], "Input",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.},
 CellChangeTimes->{{3.843109804753242*^9, 3.843109871729322*^9}, 
   3.8431105781643753`*^9, {3.8431296248847523`*^9, 3.8431296255647993`*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"cee39ec0-0cda-41a6-acdf-d2ed31e99a11"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Values", "@", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<test.exr\>\"", ",", " ", "\"\<ChannelData\>\""}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.843129156434099*^9, 3.843129168289666*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"524baaa5-aa84-40ec-a033-bd1e8362e884"],

Cell[CellGroupData[{

Cell["OneLevel", "Subitem",
 CellChangeTimes->{{3.84311758389009*^9, 
  3.843117588344742*^9}},ExpressionUUID->"aa72c1d2-8fd5-4ad3-932d-\
3cc46fa52c49"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", 
    RowBox[{"RandomImage", "[", "]"}], ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<OneLevel\>\""}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.exr\>\"", ",", " ", "\"\<ChannelData\>\""}], 
  "]"}]}], "Input",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.},
 CellChangeTimes->{{3.843117693818781*^9, 3.843117696528247*^9}, {
  3.843128954163535*^9, 3.8431289863179092`*^9}, {3.8431292170229607`*^9, 
  3.843129225972393*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"4e3db7eb-387f-4e53-aded-460583b56506"],

Cell["Ripmap", "Subitem",
 CellChangeTimes->{{3.84311758389009*^9, 
  3.843117592661386*^9}},ExpressionUUID->"f348bd05-d586-4ffc-8554-\
2a317e604f56"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", 
    RowBox[{"RandomImage", "[", "]"}], ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<Ripmap\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{"%", ",", " ", "\"\<ChannelData\>\""}], "]"}], "[", 
    "\"\<default\>\"", "]"}], ",", "10"}], "]"}]}], "Input",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.},
 CellChangeTimes->{{3.843116926551749*^9, 3.843116933912239*^9}, {
  3.843129273629387*^9, 3.843129291028528*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"c9a613c6-2189-4853-b53d-8ac5fb0ef2cf"],

Cell["Deep", "Subitem",
 CellChangeTimes->{{3.84311758389009*^9, 
  3.8431175935518427`*^9}},ExpressionUUID->"eb90e140-df57-4e0d-becf-\
2de997f45c61"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", 
    RowBox[{"RandomImage", "[", "]"}], ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<Deep\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"%", ",", " ", "\"\<Summary\>\""}], "]"}]}], "Input",
 CellChangeTimes->{{3.843129332623639*^9, 3.843129354289419*^9}, {
  3.843129391916857*^9, 3.8431294026023407`*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"bcfc8b7b-597e-420c-9a3f-11456cab9a03"],

Cell["\<\
We will generate the tiling automatically if it is not provided in mipmap:\
\>", "Item",
 CellChangeTimes->{{3.843129433720644*^9, 
  3.843129446517475*^9}},ExpressionUUID->"d8a00285-4cd3-4fe9-975a-\
9021a0b373ee"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", 
    RowBox[{"RandomImage", "[", "]"}], ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<Mipmap\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"%", ",", " ", "\"\<ChannelData\>\""}], "]"}], "[", 
   "\"\<default\>\"", "]"}], "//", "Keys"}]}], "Input",
 CellChangeTimes->{{3.843116842142538*^9, 3.843116908851591*^9}, {
  3.843125412379881*^9, 3.84312542356105*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"95f27f25-2329-48ac-bfc6-dd08724bd251"],

Cell["We also generate tiling automatically for ripmap:", "Item",
 CellChangeTimes->{{3.843129438633317*^9, 
  3.843129455262433*^9}},ExpressionUUID->"79f5d3ed-cd86-493a-a17f-\
88d42cfe1e2a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", 
    RowBox[{"RandomImage", "[", "]"}], ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<Ripmap\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Keys", "/@", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"%", ",", " ", "\"\<ChannelData\>\""}], "]"}], "[", 
   "\"\<default\>\"", "]"}]}]}], "Input",
 CellChangeTimes->{{3.843116926551749*^9, 3.843116933912239*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"862be223-5cf7-49b0-b9b9-e1203df19cbd"],

Cell["We will generate missing channels when exporting to \
\[OpenCurlyDoubleQuote]Deep\[CloseCurlyDoubleQuote]:", "Item",
 CellChangeTimes->{{3.8431294593763113`*^9, 
  3.843129463127578*^9}},ExpressionUUID->"e5133dba-c9c4-4505-b208-\
47231eefeef6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", 
    RowBox[{"RandomImage", "[", "]"}], ",", " ", 
    RowBox[{"\"\<ImageMode\>\"", " ", "->", " ", "\"\<Deep\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Keys", " ", "/@", " ", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"%", ",", " ", "\"\<ChannelData\>\""}], "]"}], "[", 
   "\"\<default\>\"", "]"}]}]}], "Input",
 CellChangeTimes->{{3.843116957830987*^9, 3.843116971595241*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"d476f313-2d37-4c51-9623-1d7ed1d99c84"],

Cell["This data does not need to be generated:", "Item",
 CellChangeTimes->{{3.843129580762553*^9, 
  3.843129590604693*^9}},ExpressionUUID->"91b1d736-4336-4899-a8f8-\
76f111993465"],

Cell[BoxData[
 RowBox[{"ii", " ", "=", " ", 
  RowBox[{"Import", "[", 
   RowBox[{"f", ",", " ", "\"\<ChannelImageList\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8431296644874067`*^9, 3.843129682877342*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"5c49aca2-7d35-4403-992c-f674fa4f3e11"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", "ii"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"iiN", " ", "=", " ", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<test.exr\>\"", ",", " ", "\"\<ChannelImageList\>\""}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.843129690388088*^9, 3.8431297178999*^9}},
 CellLabel->
  "In[221]:=",ExpressionUUID->"210d070b-7081-49b0-b485-d07a539b4c69"],

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<test.exr\>\"", ",", "\"\<Summary\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.8431297303988953`*^9, 3.8431297348897543`*^9}},
 CellLabel->
  "In[223]:=",ExpressionUUID->"5b8b3081-d578-4ae8-90cc-5ec18e22b891"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Slideshow Working",
WindowSize->{1920, 1155},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules->{
 "PresenterSettings" -> {
   "ShowNavigationBar" -> False, 
    "SlideBreakStyles" -> {"Title", "Chapter", "Section"}, "ShowSlideBreaks" -> 
    False, "Theme" -> {
     "ThemeName" -> "Facet", "FontSetName" -> "Facet", "ColorSetName" -> 
      "Default"}, "WindowSize" -> {1185, 812}, 
    "WindowMargins" -> {{32, 703}, {343, 0}}, "Dialogs" -> {}}},
FrontEndVersion->"13.0 for Mac OS X x86 (64-bit) (October 12, 2021)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"PresenterTools"}, "Facet.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData["Notebook"], 
    StyleHints -> {
     ParentList, "CodeFont" -> "Source Code Pro", 
      "ColorSet" -> {
       "Display1" -> RGBColor[0.866667, 0.0666667, 0], "Display2" -> 
        RGBColor[0.67, 0.0666667, 0], "Display3" -> 
        RGBColor[0.67, 0.0666667, 0], "Text1" -> GrayLevel[0.1], "Text2" -> 
        GrayLevel[1], "Text3" -> GrayLevel[0], "Text1Reverse" -> 
        GrayLevel[0.75], "Text2Reverse" -> GrayLevel[0.75], "Text3Reverse" -> 
        GrayLevel[0.75], "Dingbat" -> RGBColor[0.866667, 0.0666667, 0], 
        "Default" -> GrayLevel[0.1], "Background" -> GrayLevel[1]}, 
      "FontSet" -> {
       "Display1" -> "Source Sans Pro", "Display2" -> "Source Sans Pro", 
        "Display3" -> "Source Sans Pro", "Text1" -> "Source Sans Pro", 
        "Text2" -> "Source Sans Pro", "Text3" -> "Source Sans Pro", "Dingbat" -> 
        "Source Sans Pro", "Default" -> "Source Sans Pro"}, 
      "SlideBreakStyles" -> {}}], 
   Cell[
    StyleData["FirstSlide"], 
    PrivateCellOptions -> {
     "PagewiseNotebookBaseStyle" -> {
       BackgroundAppearance -> 
        FrontEnd`FileName[{"PresenterTools"}, 
          "Background-Facet-Default.png"]}}], 
   Cell[
    StyleData["Title"], FontSize -> 36, FontWeight -> "Bold", FontTracking -> 
    "Plain", FontVariations -> {"CapsType" -> "Normal"}], 
   Cell[
    CellGroupData[{
      Cell["Section", "Subsection"], 
      Cell[
       StyleData["Section"], FontTracking -> "Plain", 
       FontVariations -> {"CapsType" -> "Normal"}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], FontTracking -> "Plain", 
          FontVariations -> {"CapsType" -> "Normal"}], 
         Cell[
          StyleData["Subsection", "Slideshow Working"], FontSize -> 
          Dynamic[0.029 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]]], 
         Cell[
          StyleData["Subsection", "Slideshow Presentation"], FontSize -> 
          Dynamic[0.029 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], FontTracking -> "Plain", 
          FontVariations -> {"CapsType" -> "Normal"}], 
         Cell[
          StyleData["Subsubsection", "Slideshow Working"], FontSize -> 
          Dynamic[0.026 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]], 
          FontWeight -> "DemiBold"], 
         Cell[
          StyleData["Subsubsection", "Slideshow Presentation"], FontSize -> 
          Dynamic[0.026 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]], 
          FontWeight -> "DemiBold"], 
         Cell[
          StyleData["Subsubsubsection", "Slideshow Working"], FontSize -> 
          Dynamic[0.026 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]], 
          FontWeight -> "DemiBold", FontTracking -> "Plain"], 
         Cell[
          StyleData["Subsubsubsection", "Slideshow Presentation"], FontSize -> 
          Dynamic[0.026 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]], 
          FontWeight -> "DemiBold", FontTracking -> "Plain"], 
         Cell[
          StyleData["Subsubsubsubsection", "Slideshow Working"], FontSize -> 
          Dynamic[0.026 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]]], 
         Cell[
          StyleData["Subsubsubsubsection", "Slideshow Presentation"], 
          FontSize -> 
          Dynamic[0.026 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], FontSize -> 13], 
         Cell[
          StyleData["InputOnly", "SlideShow"], 
          CellMargins -> {{100, 10}, {8, 15}}], 
         Cell[
          StyleData["InputOnly", "Slideshow Working"], CellMargins -> 
          Dynamic[{{
             0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
              FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {
             0.00992593 FrontEnd`AbsoluteCurrentValue[{WindowSize, 2}], 
              0.0186111 FrontEnd`AbsoluteCurrentValue[{WindowSize, 2}]}}], 
          LinebreakAdjustments -> {1, 2., 12., 1., 1.}, FontSize -> 
          Dynamic[0.019 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]]], 
         Cell[
          StyleData[
          "InputOnly", "Slideshow Presentation", StyleDefinitions -> 
           StyleData["InputOnly", "Slideshow Working"]]], 
         Cell[
          StyleData[
          "InputOnly", "Scrolling Presentation", StyleDefinitions -> 
           StyleData["InputOnly", "Slideshow Working"]]], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}, 
          LinebreakAdjustments -> {0.85, 2, 10, 1, 1}]}, Open]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "13.0 for Mac OS X x86 (64-bit) (October 12, 2021)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"3e371164-d3c4-49a1-8a9b-c3968f4a8b4f"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[580, 22, 169, 3, 57, "SlideShowNavigationBar",ExpressionUUID->"ae861ed8-5fa1-4088-84fd-2651cc7b368a",
   CellTags->"SlideShowHeader"],
  Cell[1209, 44, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"ee3ea2a1-973b-4e9a-a704-0d8a3c30d1be",
   CellTags->"SlideShowHeader"],
  Cell[2615, 79, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"4e8e5a7c-8b4e-47e7-a75d-3cb2b655ed51",
   CellTags->"SlideShowHeader"],
  Cell[143916, 2817, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"fb1d229e-4f05-43ff-ba6b-7eedb3e0b0b2",
   CellTags->"SlideShowHeader"],
  Cell[336291, 6078, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"20d3af15-f3ae-4b4a-b9ae-9d4bbf712881",
   CellTags->"SlideShowHeader"],
  Cell[341443, 6234, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"ee72f595-b7a5-4406-9840-45a929451f5d",
   CellTags->"SlideShowHeader"],
  Cell[346808, 6392, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"966b4952-2666-4de3-9597-e79d88e4d035",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 368469, 6985}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 169, 3, 57, "SlideShowNavigationBar",ExpressionUUID->"ae861ed8-5fa1-4088-84fd-2651cc7b368a",
 CellTags->"SlideShowHeader"],
Cell[752, 27, 189, 6, 582, "Title",ExpressionUUID->"8b1642a0-c2f2-4832-b962-da68c26a4047"],
Cell[944, 35, 228, 4, 154, "Subtitle",ExpressionUUID->"75c0d664-a0db-4889-a1b0-650f7c83e5d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1209, 44, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"ee3ea2a1-973b-4e9a-a704-0d8a3c30d1be",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1356, 50, 429, 8, 179, "Section",ExpressionUUID->"75e785bd-e551-42c4-b918-1ff722dfcee0"],
Cell[1788, 60, 778, 13, 628, "Text",ExpressionUUID->"98832863-8e01-4636-a116-f2d361af161b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2615, 79, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"4e8e5a7c-8b4e-47e7-a75d-3cb2b655ed51",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2762, 85, 306, 7, 179, "Section",ExpressionUUID->"bf6b684b-be70-47c1-be5a-c3838a1d25c9"],
Cell[CellGroupData[{
Cell[3093, 96, 163, 3, 123, "Subsection",ExpressionUUID->"9e8c88a7-092a-4234-be6e-e6e70c1a3797"],
Cell[CellGroupData[{
Cell[3281, 103, 170, 3, 92, "Item",ExpressionUUID->"d36d72ec-fab4-4ccb-bcda-a4b7cf2f2ae8"],
Cell[CellGroupData[{
Cell[3476, 110, 150, 3, 87, "Subitem",ExpressionUUID->"f1baa397-a5b1-4c30-bf87-0a7bdffdb995"],
Cell[3629, 115, 153, 3, 87, "Subitem",ExpressionUUID->"2bb1f54c-b682-46e6-8d23-e009f051e4ff"],
Cell[3785, 120, 148, 3, 87, "Subitem",ExpressionUUID->"cd7db606-7f17-4231-ab20-193990cfad34"],
Cell[3936, 125, 150, 3, 87, "Subitem",ExpressionUUID->"73bf84a1-cf71-49d0-9fc7-125ee95ae0c1"]
}, Open  ]]
}, Open  ]],
Cell[4113, 132, 465, 11, 79, "Input",ExpressionUUID->"502b6fd1-3c50-42a2-8f4c-fa190536c5cd"],
Cell[4581, 145, 219, 3, 79, "Input",ExpressionUUID->"acb54648-ea26-4c7f-9280-9ed3909d3153"],
Cell[4803, 150, 258, 4, 79, "Input",ExpressionUUID->"d7fc74b4-8a2e-4fa6-bcc2-e9106fcbcf5c"]
}, Closed]],
Cell[CellGroupData[{
Cell[5098, 159, 211, 4, 92, "Subsection",ExpressionUUID->"af202b17-41eb-486b-b6a8-4e200549af59"],
Cell[5312, 165, 184, 3, 92, "Item",ExpressionUUID->"790df0b5-52bc-4936-8497-57fae21c84ff"],
Cell[5499, 170, 29775, 532, 199, "Input",ExpressionUUID->"715fecb0-b941-4c6c-8ba2-d6f8afc233fa"],
Cell[35277, 704, 247, 4, 92, "Item",ExpressionUUID->"d0cedc16-6bfd-4dce-87f3-573203ba9d0b"],
Cell[35527, 710, 762, 19, 138, "Input",ExpressionUUID->"a1f14626-5810-40fd-9f5b-588a1745c6ef"],
Cell[36292, 731, 312, 6, 79, "Input",ExpressionUUID->"11300029-3b7e-49d4-90f6-bbd6aecf00f3"],
Cell[36607, 739, 165, 3, 92, "Item",ExpressionUUID->"62a72e39-8e66-4899-997e-8798ab9e0fe2"],
Cell[36775, 744, 561, 15, 138, "Input",ExpressionUUID->"df682cf9-4703-4999-80c0-74111c847179"],
Cell[37339, 761, 260, 5, 79, "Input",ExpressionUUID->"44db3ed2-8f32-41c6-92f2-ef075ec03fc0"],
Cell[37602, 768, 325, 7, 79, "Input",ExpressionUUID->"cd0c602f-eed9-42f2-a7d6-b8f94a328630"],
Cell[37930, 777, 215, 5, 92, "Item",ExpressionUUID->"5271e6fc-a5d1-4fbf-8558-1cab99dd2507"],
Cell[38148, 784, 12130, 289, 148, "Input",ExpressionUUID->"7ff07c76-a44f-42e6-9d88-f52ba37b00d6"],
Cell[50281, 1075, 861, 23, 181, "Input",ExpressionUUID->"9d0c3ab6-f4de-4378-92e5-757b26e5779a"]
}, Closed]],
Cell[CellGroupData[{
Cell[51179, 1103, 164, 3, 92, "Subsection",ExpressionUUID->"aef62cb9-b7a5-455a-b635-362bd44052d4"],
Cell[51346, 1108, 495, 12, 79, "Input",ExpressionUUID->"62944768-0ff4-4af2-840f-e20654c1efe6"],
Cell[51844, 1122, 309, 6, 79, "Input",ExpressionUUID->"72daceaa-a054-4622-ad1d-8530c54499c4"],
Cell[52156, 1130, 276, 6, 79, "Input",ExpressionUUID->"8d552502-2804-40e8-ad87-cc52fdf25213"]
}, Closed]],
Cell[CellGroupData[{
Cell[52469, 1141, 176, 3, 92, "Subsection",ExpressionUUID->"6e4a22cb-89c2-4cc6-9984-e41a25b45457"],
Cell[52648, 1146, 1394, 32, 254, "Input",ExpressionUUID->"9056215b-2d11-457c-8a75-769ab056e1e4"],
Cell[54045, 1180, 194, 4, 79, "Input",ExpressionUUID->"f00fa283-326d-4a0e-8093-b259688cb525"],
Cell[54242, 1186, 208, 5, 79, "Input",ExpressionUUID->"86207e90-a9de-448c-b85a-a9558e217214"],
Cell[54453, 1193, 29475, 529, 133, "Input",ExpressionUUID->"b80b1830-73e9-45cf-8a25-a92bd435e011"],
Cell[83931, 1724, 194, 4, 79, "Input",ExpressionUUID->"a43d9c84-9a4c-4b05-9163-9d08117d5647"],
Cell[84128, 1730, 29806, 537, 217, "Input",ExpressionUUID->"a562a10d-d979-4572-8933-592a123a1ee7"],
Cell[113937, 2269, 29641, 533, 217, "Input",ExpressionUUID->"945cf3bd-254d-4afe-a189-4a450799bea7"],
Cell[143581, 2804, 274, 6, 79, "Input",ExpressionUUID->"b0bdd946-8ceb-4f6b-852b-73875e71ee31"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[143916, 2817, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"fb1d229e-4f05-43ff-ba6b-7eedb3e0b0b2",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[144063, 2823, 301, 7, 179, "Section",ExpressionUUID->"f9102330-02a2-4f44-954f-2c22f3d4059d"],
Cell[CellGroupData[{
Cell[144389, 2834, 165, 3, 123, "Subsection",ExpressionUUID->"94433b83-8744-4c30-a97d-0e8d50b96015"],
Cell[CellGroupData[{
Cell[144579, 2841, 221, 5, 157, "Item",ExpressionUUID->"0d17a0c2-0a35-40ae-a3b1-2492d873cf77"],
Cell[144803, 2848, 218, 5, 92, "Item",ExpressionUUID->"a7688235-4462-4ea5-866a-54fcd77a5c10"],
Cell[145024, 2855, 290, 4, 92, "Item",ExpressionUUID->"3d0f2da8-7154-4dba-bc84-e72b8a3b8aa3"]
}, Open  ]],
Cell[145329, 2862, 291, 6, 79, "Input",ExpressionUUID->"07cc6131-902d-4223-be1f-69122bacb5cf"]
}, Closed]],
Cell[CellGroupData[{
Cell[145657, 2873, 186, 3, 92, "Subsection",ExpressionUUID->"05a8af4e-ec8e-4bad-980f-9ef10c26e728"],
Cell[145846, 2878, 189, 3, 92, "Text",ExpressionUUID->"84214557-791c-4daa-8bd8-886d400f827b"],
Cell[146038, 2883, 150, 3, 92, "Item",ExpressionUUID->"67bab06a-1b30-47ec-8eb3-02d8344d4947"],
Cell[146191, 2888, 185184, 3041, 503, "Input",ExpressionUUID->"1cdc70d2-fe3a-471e-9bcd-e5baa4881611"],
Cell[331378, 5931, 151, 3, 92, "Item",ExpressionUUID->"9d7829d8-bdf9-4c35-96d2-0e5803e8c3d6"],
Cell[331532, 5936, 291, 6, 79, "Input",ExpressionUUID->"7ad7d03d-29ec-4353-a389-79afbc72d64b"],
Cell[331826, 5944, 289, 6, 79, "Input",ExpressionUUID->"63a64b00-aaf4-403a-ab0d-895613193b4a"],
Cell[CellGroupData[{
Cell[332140, 5954, 313, 6, 157, "Item",ExpressionUUID->"41028d98-47c2-4a7e-bf97-8a9970895bbc"],
Cell[332456, 5962, 346, 7, 79, "Input",ExpressionUUID->"a3d94ee7-368e-4b90-9b50-a250856b689f",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15000.}],
Cell[332805, 5971, 378, 8, 157, "Item",ExpressionUUID->"030c5a2a-8b7d-4c96-84c8-00c57beff5a1"]
}, Open  ]],
Cell[333198, 5982, 330, 8, 79, "Input",ExpressionUUID->"02b02fdf-31e1-4f03-a154-016fbbe3729f"],
Cell[333531, 5992, 460, 10, 79, "Input",ExpressionUUID->"090d2991-ffe3-4eea-beff-622185bc466a"],
Cell[333994, 6004, 328, 8, 79, "Input",ExpressionUUID->"e6b890f0-8941-42ac-ad3e-a3d1afdc4873"],
Cell[334325, 6014, 334, 8, 79, "Input",ExpressionUUID->"c5bcbb6f-7253-4bcd-a233-7f099b59328b"],
Cell[334662, 6024, 272, 7, 79, "Input",ExpressionUUID->"d20e8a26-7d0a-473a-8dbc-a37865caf241"],
Cell[334937, 6033, 374, 9, 79, "Input",ExpressionUUID->"cf3b0bf8-33d2-4c40-9ec5-fd7c40818979"]
}, Closed]],
Cell[CellGroupData[{
Cell[335348, 6047, 168, 3, 92, "Subsection",ExpressionUUID->"d247fcf2-1e76-4774-9515-830887f1bb26"],
Cell[335519, 6052, 372, 9, 79, "Input",ExpressionUUID->"b5e20b74-33de-40d9-a870-80fccfde4931"],
Cell[335894, 6063, 336, 8, 79, "Input",ExpressionUUID->"40c27140-00db-49bf-8f2e-e5982f3adbb6"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[336291, 6078, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"20d3af15-f3ae-4b4a-b9ae-9d4bbf712881",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[336438, 6084, 357, 8, 179, "Section",ExpressionUUID->"fb032533-9e15-4ad9-9c11-cf8b37caba6a"],
Cell[CellGroupData[{
Cell[336820, 6096, 216, 4, 123, "Subsection",ExpressionUUID->"92eeb66d-3c21-4719-8069-c50e22f936bd"],
Cell[337039, 6102, 233, 6, 159, "Text",ExpressionUUID->"98e44468-7f7c-4777-8e4d-fe7fd190da10"],
Cell[337275, 6110, 406, 11, 138, "Input",ExpressionUUID->"22572d49-3106-4caf-9aff-587f6a8f26a3"],
Cell[337684, 6123, 472, 13, 138, "Input",ExpressionUUID->"4bb1ee03-270f-4e26-b671-00589bcc0577"],
Cell[338159, 6138, 351, 8, 79, "Input",ExpressionUUID->"7bec33e2-e564-4c72-8136-f86d3f295b71"],
Cell[338513, 6148, 254, 5, 79, "Input",ExpressionUUID->"03a70506-1529-4750-baee-81099ec00b3e"],
Cell[338770, 6155, 259, 5, 79, "Input",ExpressionUUID->"55f1c796-aa1f-4e44-81c5-906d4b38939f"],
Cell[339032, 6162, 259, 5, 79, "Input",ExpressionUUID->"68245f65-a9f9-43df-ad59-c1f05a624e29"],
Cell[339294, 6169, 255, 5, 79, "Input",ExpressionUUID->"d6885c86-11b9-4edf-b911-7d5461353fcd"],
Cell[339552, 6176, 262, 5, 79, "Input",ExpressionUUID->"f70d8f58-328e-49f7-94b8-36810df54ef4"],
Cell[339817, 6183, 254, 5, 79, "Input",ExpressionUUID->"8453ac88-dd61-4b71-b7ed-d5a8f9741429"],
Cell[340074, 6190, 527, 15, 138, "Input",ExpressionUUID->"c1ec9ce7-6a1e-4e56-987c-aa4046284a7f"],
Cell[340604, 6207, 449, 11, 138, "Input",ExpressionUUID->"40764ba5-6208-42ed-9cc0-834943bb78a7"],
Cell[341056, 6220, 326, 7, 79, "Input",ExpressionUUID->"bf9e2ce1-477c-4b07-8cb9-34aad0853b5a"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[341443, 6234, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"ee72f595-b7a5-4406-9840-45a929451f5d",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[341590, 6240, 391, 8, 179, "Section",ExpressionUUID->"5234083a-e6d4-4181-9c3a-0d08c04cbf2d"],
Cell[341984, 6250, 326, 7, 79, "Output",ExpressionUUID->"6e5c6120-603e-4197-b69c-88f322a55619"],
Cell[CellGroupData[{
Cell[342335, 6261, 222, 4, 123, "Subsection",ExpressionUUID->"a32bcbef-6de5-4cba-b9be-88122ec4796e"],
Cell[342560, 6267, 161, 3, 92, "Item",ExpressionUUID->"986791e9-ea5f-4be3-9fca-0f3611c3e843"],
Cell[342724, 6272, 339, 8, 79, "Input",ExpressionUUID->"04c86c75-6e04-43c6-83d9-26d3645bfeaf"],
Cell[343066, 6282, 236, 4, 79, "Input",ExpressionUUID->"d6b92618-ca39-48cd-a11b-65d1a5777218"],
Cell[343305, 6288, 329, 7, 79, "Input",ExpressionUUID->"409775cf-e8ff-47fb-91ee-f8a67c43d623"],
Cell[343637, 6297, 380, 8, 79, "Input",ExpressionUUID->"b7c4b013-5b9c-417d-9987-83e67161a51b"],
Cell[344020, 6307, 212, 5, 79, "Input",ExpressionUUID->"5e62f92a-ef4c-467f-b1ed-ca3f72306037"],
Cell[344235, 6314, 272, 5, 79, "Input",ExpressionUUID->"60e43aa3-abbf-4557-a4ca-70e8627241d2"],
Cell[344510, 6321, 276, 5, 79, "Input",ExpressionUUID->"f14980a4-d1c8-45e8-81f2-d1def83bb7c0"],
Cell[344789, 6328, 348, 8, 79, "Input",ExpressionUUID->"ab45a5ce-7b8a-43a2-bc24-427beaba2db7"]
}, Closed]],
Cell[CellGroupData[{
Cell[345174, 6341, 170, 3, 92, "Subsection",ExpressionUUID->"0ca39841-31dc-4eda-85b0-750e251d0fc4"],
Cell[345347, 6346, 247, 5, 79, "Input",ExpressionUUID->"a6218883-a7ad-4feb-bfd4-625994dfde80"],
Cell[345597, 6353, 238, 4, 79, "Input",ExpressionUUID->"45cd8581-c52b-4001-88da-9e0fb460c7c5"]
}, Closed]],
Cell[CellGroupData[{
Cell[345872, 6362, 168, 3, 92, "Subsection",ExpressionUUID->"64e7630e-e4a0-40e1-ab98-c0e862e0bc8c"],
Cell[346043, 6367, 223, 5, 79, "Input",ExpressionUUID->"9bf064bc-30f7-47b9-880a-50b05ab35e5a"],
Cell[346269, 6374, 213, 4, 79, "Input",ExpressionUUID->"884a7ef0-afb8-41ee-98f4-0bba34a26e4e"],
Cell[346485, 6380, 262, 5, 79, "Input",ExpressionUUID->"75785077-8cc0-435a-ad8a-eee8e8f0e575"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[346808, 6392, 122, 2, 60, "SlideShowNavigationBar",ExpressionUUID->"966b4952-2666-4de3-9597-e79d88e4d035",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[346955, 6398, 309, 7, 179, "Section",ExpressionUUID->"bb2d9296-607e-4543-a96d-ff70c4aa835c"],
Cell[CellGroupData[{
Cell[347289, 6409, 153, 3, 123, "Subsection",ExpressionUUID->"f2659b91-a3ef-4e50-a6c4-70611f561549"],
Cell[347445, 6414, 331, 8, 138, "Input",ExpressionUUID->"a2b1075b-1b86-4487-bbe7-7ff27d324531"],
Cell[347779, 6424, 315, 7, 79, "Input",ExpressionUUID->"d7414e1c-6151-4a4f-bfda-6bedb8b061cf"],
Cell[348097, 6433, 206, 4, 79, "Input",ExpressionUUID->"0af881bd-f66e-495c-aa24-9010a6d3f9f8"],
Cell[348306, 6439, 317, 7, 79, "Input",ExpressionUUID->"801d1519-a7c5-4117-8e25-125e1fba23dc"],
Cell[348626, 6448, 210, 4, 79, "Input",ExpressionUUID->"128195d6-c4be-49fc-a337-18b4535a5956"]
}, Closed]],
Cell[CellGroupData[{
Cell[348873, 6457, 210, 4, 92, "Subsection",ExpressionUUID->"9ff6d0f7-f9d4-4716-9a0e-17c12606d315"],
Cell[CellGroupData[{
Cell[349108, 6465, 154, 3, 89, "Subsubsection",ExpressionUUID->"541bc338-309f-4b63-9b51-2ca0fa1dc93c"],
Cell[349265, 6470, 192, 3, 92, "Item",ExpressionUUID->"0b13af1d-337e-4a70-8d3d-8234b7e9d2fe"],
Cell[349460, 6475, 664, 16, 138, "Input",ExpressionUUID->"d37bf2fd-281e-40f6-89e1-3ad156c64ded"],
Cell[350127, 6493, 212, 5, 92, "Item",ExpressionUUID->"49484571-95c2-4428-8de7-c4db6d2fa19d"],
Cell[350342, 6500, 278, 6, 79, "Input",ExpressionUUID->"09307db1-b350-4100-929d-5a88dee0c42e"],
Cell[350623, 6508, 676, 17, 196, "Input",ExpressionUUID->"4196d367-c430-483d-96e3-2311411d02c8"],
Cell[351302, 6527, 172, 3, 92, "Item",ExpressionUUID->"a1f6b087-9124-4445-a9f1-94a531e4e456"],
Cell[351477, 6532, 430, 10, 138, "Input",ExpressionUUID->"1e9f9edd-f3a3-46e5-8aaa-f588ef9adb7e"],
Cell[351910, 6544, 442, 11, 138, "Input",ExpressionUUID->"a738c2c6-e3c1-498d-8542-bfb72b0f4985"],
Cell[352355, 6557, 366, 9, 79, "Input",ExpressionUUID->"0e41c7f1-e9cd-4611-a888-4c89a85d1f1c"]
}, Closed]],
Cell[CellGroupData[{
Cell[352758, 6571, 155, 3, 72, "Subsubsection",ExpressionUUID->"aa326e3e-0daf-4fc4-a1c8-6ac53a3823fa"],
Cell[352916, 6576, 162, 2, 92, "Text",ExpressionUUID->"82d7a31a-84e2-4aec-9816-c870a483d61e"],
Cell[353081, 6580, 613, 15, 138, "Input",ExpressionUUID->"a4c07aa0-936a-420a-a679-e5c5d96c23f2"]
}, Closed]],
Cell[CellGroupData[{
Cell[353731, 6600, 158, 3, 72, "Subsubsection",ExpressionUUID->"ed876217-607c-4947-8ef2-6fbd65a9aa5e"],
Cell[CellGroupData[{
Cell[353914, 6607, 303, 7, 157, "Item",ExpressionUUID->"b2588e95-711f-45f1-b066-04b238e273b5"],
Cell[CellGroupData[{
Cell[354242, 6618, 152, 3, 87, "Subitem",ExpressionUUID->"d9428bf0-374e-43c7-a576-36e387959a49"],
Cell[354397, 6623, 596, 14, 138, "Input",ExpressionUUID->"5d85d0f2-4cef-4385-a117-61e4ee3c4a29",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.}],
Cell[354996, 6639, 211, 4, 87, "Subitem",ExpressionUUID->"cbfd2387-7f6a-40a4-b99d-72752f86bd99",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.}],
Cell[355210, 6645, 980, 23, 254, "Input",ExpressionUUID->"cee39ec0-0cda-41a6-acdf-d2ed31e99a11",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.}]
}, Open  ]]
}, Open  ]],
Cell[356217, 6672, 323, 8, 79, "Input",ExpressionUUID->"524baaa5-aa84-40ec-a033-bd1e8362e884"],
Cell[CellGroupData[{
Cell[356565, 6684, 152, 3, 87, "Subitem",ExpressionUUID->"aa72c1d2-8fd5-4ad3-932d-3cc46fa52c49"],
Cell[356720, 6689, 680, 15, 138, "Input",ExpressionUUID->"4e3db7eb-387f-4e53-aded-460583b56506",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.}],
Cell[357403, 6706, 150, 3, 87, "Subitem",ExpressionUUID->"f348bd05-d586-4ffc-8554-2a317e604f56"],
Cell[357556, 6711, 715, 17, 138, "Input",ExpressionUUID->"c9a613c6-2189-4853-b53d-8ac5fb0ef2cf",
 CellGroupingRules->{"GroupTogetherNestedGrouping", 15100.}],
Cell[358274, 6730, 150, 3, 87, "Subitem",ExpressionUUID->"eb90e140-df57-4e0d-becf-2de997f45c61"]
}, Open  ]],
Cell[358439, 6736, 541, 12, 138, "Input",ExpressionUUID->"bcfc8b7b-597e-420c-9a3f-11456cab9a03"],
Cell[358983, 6750, 224, 5, 92, "Item",ExpressionUUID->"d8a00285-4cd3-4fe9-975a-9021a0b373ee"],
Cell[359210, 6757, 620, 15, 138, "Input",ExpressionUUID->"95f27f25-2329-48ac-bfc6-dd08724bd251"],
Cell[359833, 6774, 191, 3, 92, "Item",ExpressionUUID->"79f5d3ed-cd86-493a-a17f-88d42cfe1e2a"],
Cell[360027, 6779, 572, 14, 138, "Input",ExpressionUUID->"862be223-5cf7-49b0-b9b9-e1203df19cbd"],
Cell[360602, 6795, 250, 4, 92, "Item",ExpressionUUID->"e5133dba-c9c4-4505-b208-47231eefeef6"],
Cell[360855, 6801, 580, 14, 138, "Input",ExpressionUUID->"d476f313-2d37-4c51-9623-1d7ed1d99c84"],
Cell[361438, 6817, 182, 3, 92, "Item",ExpressionUUID->"91b1d736-4336-4899-a8f8-76f111993465"],
Cell[361623, 6822, 296, 6, 79, "Input",ExpressionUUID->"5c49aca2-7d35-4403-992c-f674fa4f3e11"],
Cell[361922, 6830, 440, 11, 138, "Input",ExpressionUUID->"210d070b-7081-49b0-b485-d07a539b4c69"],
Cell[362365, 6843, 264, 5, 79, "Input",ExpressionUUID->"5b8b3081-d578-4ae8-90cc-5ec18e22b891"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

